(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    213816,       5361]*)
(*NotebookOutlinePosition[    214478,       5384]*)
(*  CellTagsIndexPosition[    214434,       5380]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\ 
        This\ mathematica\ file\ creates\ Fig\ 5\ of\ the\ paper\ *) \),
      FontSize->24]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ 
        Set\ the\ directory, \ \(switch\ off\ warning\ messages\  &\)\ load\ \
add - ons\ *) \),
      FontSize->24]], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["SetDirectory",
          FontColor->RGBColor[1, 0, 0]], "[", "\"\<D:\\dL_project\\data\>\"", 
        "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{\($TextStyle = {FontFamily \[Rule] "\<Times\>", 
          FontSize \[Rule] 16}\), ";", 
      RowBox[{"Off", 
        StyleBox["[",
          "MR"], 
        RowBox[{\(General::spell\), ",", 
          StyleBox[\(General::spell1\),
            "MR"], ",", \(NIntegrate::"\<inum\>"\), 
          ",", \(ContourGraphics::"\<ctpnt\>"\), 
          ",", \(NIntegrate::"\<ncvb\>"\), 
          ",", \(NIntegrate::"\<slwcon\>"\)}], 
        StyleBox["]",
          "MR"]}], 
      StyleBox[";",
        "MR"]}], "\[IndentingNewLine]", \(<< Graphics`Graphics`; << 
      Graphics`ImplicitPlot`; << Graphics`FilledPlot`;\)}], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["(*",
        FontSize->24], 
      StyleBox[" ",
        FontSize->24], 
      RowBox[{
        StyleBox["Select",
          FontSize->24], 
        StyleBox[" ",
          FontSize->24], 
        SubscriptBox[
          StyleBox["\[CapitalOmega]",
            FontSize->24], "M"]}], 
      StyleBox[" ",
        FontSize->24], 
      StyleBox["*)",
        FontSize->24]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["om0",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["=",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["0.24",
          FontColor->RGBColor[0, 0, 1]]}], 
      StyleBox[";",
        FontColor->RGBColor[0, 0, 1]]}]], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Read\ data\ *) \),
      FontSize->24]], "Input"],

Cell[BoxData[{
    \(\(ndat2 = 115;\)\), "\n", 
    \(\(sint = 0.138;\)\), "\[IndentingNewLine]", 
    \(\(datasnls = 
        ReadList["\<snls_115.txt\>", {Number, Number, Number}];\)\), "\n", 
    \(\(zs = datasnls[\([#1, 1]\)] &;\)\), "\n", 
    \(\(mi = datasnls[\([#1, 2]\)] &;\)\), "\n", 
    \(\(smi = datasnls[\([#1, 3]\)] &;\)\)}], "Input"],

Cell[BoxData[
    StyleBox[\( (*\ Define\ model\ *) \),
      FontSize->24]], "Input"],

Cell[BoxData[{
    \(cgeff = 15/4; 
    Geff[x_, c_] := 1 + c\ x^2\/\((1 + x)\)^2;\), "\[IndentingNewLine]", 
    \(\(H[a_, om_, w0_, w1_] := \ 
        Sqrt[om*a\^\(-3\) + \((1 - om)\)*a^\((\(-3\) \((1 + w0 + w1)\))\) 
              Exp[3\ w1 \((a - 1)\)]];\)\), "\n", 
    \(\(f[x_, omt_, w0_, w1_] := 1/H[1\/\(1 + x\), omt, w0, w1];\)\), "\n", 
    \(\(rr[xx_, omt_, w0_, w1_, c_] := 
        NIntegrate[f[x, omt, w0, w1]/\@Geff[x, c], {x, 0, xx}];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["(*",
        FontSize->24], 
      StyleBox[" ",
        FontSize->24], 
      RowBox[{
        StyleBox["Construct",
          FontSize->24], 
        StyleBox[" ",
          FontSize->24], 
        SuperscriptBox[
          StyleBox["\[Chi]",
            FontSize->24], "2"]}], 
      StyleBox[" ",
        FontSize->24], 
      StyleBox["*)",
        FontSize->24]}]], "Input"],

Cell[BoxData[{
    \(\(chi2fa2[w0_, w1_, c_] := 
        Sum[\((mi[i] - 
                  5\ Log[10, rr[zs[i], om0, w0, w1, c]*\((1 + zs[i])\)] - 
                  cgeff\ Log[10, Geff[zs[i], c]])\)^2/\((smi[i]^2 + 
                sint^2)\), {i, 1, ndat2}];\)\), "\n", 
    \(\(chi2fb2[w0_, w1_, c_] := 
        Sum[\((mi[i] - 
                5\ Log[10, rr[zs[i], om0, w0, w1, c]*\((1 + zs[i])\)] - 
                cgeff\ Log[10, Geff[zs[i], c]])\)/\((smi[i]^2 + 
                sint^2)\), {i, 1, ndat2}];\)\), "\n", 
    \(\(chi2fc2 = 
        Sum[1/\((smi[i]^2 + sint^2)\), {i, 1, 
            ndat2}];\)\), "\[IndentingNewLine]", 
    \(\(chi2total[w0_, w1_, c_] := 
        chi2fa2[w0, w1, c] - chi2fb2[w0, w1, c]^2/chi2fc2;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          Use\ a\ prior\ from\ nucleosynthesis\ \[CapitalDelta]G/
                G\  \[Rule] \ 20  %\ *) \),
        FontSize->18], 
      "\[IndentingNewLine]", \(Print["\<\[Alpha] = \>", \[Alpha] = \(Solve[
              Limit[Geff[z, c], z \[Rule] \[Infinity]] \[Equal] 1.2, 
              c]\)[\([1, 1, 2]\)]]\)}]], "Input"],

Cell[BoxData[
    InterpretationBox[\("\[Alpha] = "\[InvisibleSpace]0.19999999999999996`\),
      SequenceForm[ "\[Alpha] = ", .19999999999999996],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ Minimize\ the\ \[Chi]\^2\ *) \),
        FontSize->18], 
      "\[IndentingNewLine]", \(chi2min = 
        FindMinimum[
          chi2total[w0, w1, 
            0], {{w0, \(-1\), \(-1.01\)}, {w1, \(-1.3\), \(-1.31\)}}]\)}]], \
"Input"],

Cell[BoxData[
    \({104.62256660684943`, {w0 \[Rule] \(-1.0127398829944514`\), 
        w1 \[Rule] 0.37020391768484184`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(chi2min1 = 
      FindMinimum[
        chi2total[w0, 
          w1, \[Alpha]], {{w0, \(-1\), \(-1.01\)}, {w1, \(-1.3\), \
\(-1.31\)}}]\)], "Input"],

Cell[BoxData[
    \({104.63127437233925`, {w0 \[Rule] \(-1.0176521041390094`\), 
        w1 \[Rule] 0.9576584328010607`}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ The\ 1  \[Sigma]\ and\ 2  \[Sigma]\ bounds\ *) \),
      FontSize->24]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p1s1 = 
      FindRoot[{chi2total[w0, w1, \[Alpha]] - chi2min1[\([1]\)] - 
              2.3 \[Equal] 0, 
          D[chi2total[w0, w1, \[Alpha]], w1] \[Equal] 
            0}, {{w0, \(- .2\)}, {w1, \(-4\)}}]\), "\n", 
    \(p1s2 = 
      FindRoot[{chi2total[w0, w1, \[Alpha]] - chi2min1[\([1]\)] - 
              2.3 \[Equal] 0, 
          D[chi2total[w0, w1, \[Alpha]], w1] \[Equal] 
            0}, {{w0, \(-1.7\)}, {w1, 5.2}}]\), "\[IndentingNewLine]", 
    \(p2s1 = 
      FindRoot[{chi2total[w0, w1, \[Alpha]] - chi2min1[\([1]\)] - 
              6.17 \[Equal] 0, 
          D[chi2total[w0, w1, \[Alpha]], w1] \[Equal] 
            0}, {{w0, \(- .2\)}, {w1, \(-4\)}}]\), "\[IndentingNewLine]", 
    \(p2s2 = 
      FindRoot[{chi2total[w0, w1, \[Alpha]] - chi2min1[\([1]\)] - 
              6.17 \[Equal] 0, 
          D[chi2total[w0, w1, \[Alpha]], w1] \[Equal] 
            0}, {{w0, \(-1.7\)}, {w1, 5.2}}]\)}], "Input"],

Cell[BoxData[
    \({w0 \[Rule] \(-0.5176910707406616`\), 
      w1 \[Rule] \(-2.090624360097913`\)}\)], "Output"],

Cell[BoxData[
    \({w0 \[Rule] \(-1.5208828002050896`\), 
      w1 \[Rule] 3.9345181909607394`}\)], "Output"],

Cell[BoxData[
    \({w0 \[Rule] \(-0.19675703090731755`\), 
      w1 \[Rule] \(-4.108810006578347`\)}\)], "Output"],

Cell[BoxData[
    \({w0 \[Rule] \(-1.8474845671192177`\), 
      w1 \[Rule] 5.831419852159346`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    StyleBox[\( (*\ Contour\ plot\ *) \),
      FontSize->24]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(imp1sw = 
      ImplicitPlot[
          chi2total[w0, w1, \[Alpha]] \[Equal] 
            chi2min1[\([1]\)] + 
              2.30, {w0, \(- .4\), \(-1.6\)}, {w1, \(-2.5\), 4.5}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] Identity] // 
        Timing\), "\[IndentingNewLine]", 
    \(imp2sw = 
      ImplicitPlot[
          chi2total[w0, w1, \[Alpha]] \[Equal] 
            chi2min1[\([1]\)] + 6.17, {w0,  .3, \(-2\)}, {w1, \(-5\), 6}, 
          AspectRatio \[Rule] 1, DisplayFunction \[Rule] Identity] // 
        Timing\), "\[IndentingNewLine]", 
    \(\(impwcc = 
        Show[imp1sw[\([2]\)], imp2sw[\([2]\)], 
          Graphics[{RGBColor[0, 0, 1], 
              Disk[{chi2min1[\([2, 1, 2]\)], chi2min1[\([2, 2, 2]\)]}, { .02, 
                  0.1}]}], 
          PlotRange \[Rule] {{\(- .1\), \(-2\)}, {\(-5\), 6}}, 
          AspectRatio \[Rule] 1, Frame \[Rule] True, 
          FrameLabel \[Rule] {\*"\"\<\!\(w\_0\)\>\"", \
\*"\"\<\!\(w\_1\)\>\""}, Axes \[Rule] False, 
          DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(255.76599999999996`\ Second\), ",", 
        TagBox[\(\[SkeletonIndicator]  
            ContourGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(258.10900000000004`\ Second\), ",", 
        TagBox[\(\[SkeletonIndicator]  
            ContourGraphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.05263 0.526316 0.454545 0.0909091 [
[.13158 -0.0125 -21.5313 -20.125 ]
[.13158 -0.0125 21.5313 0 ]
[.26316 -0.0125 -17.5313 -20.125 ]
[.26316 -0.0125 17.5313 0 ]
[.39474 -0.0125 -21.5313 -20.125 ]
[.39474 -0.0125 21.5313 0 ]
[.52632 -0.0125 -11.5625 -20.125 ]
[.52632 -0.0125 11.5625 0 ]
[.65789 -0.0125 -21.5313 -20.125 ]
[.65789 -0.0125 21.5313 0 ]
[.78947 -0.0125 -17.5313 -20.125 ]
[.78947 -0.0125 17.5313 0 ]
[.92105 -0.0125 -21.5313 -20.125 ]
[.92105 -0.0125 21.5313 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -10.875 -40.25 ]
[.5 -0.0125 10.875 -20.125 ]
[-0.0125 .09091 -23.125 -10.0625 ]
[-0.0125 .09091 0 10.0625 ]
[-0.0125 .27273 -23.125 -10.0625 ]
[-0.0125 .27273 0 10.0625 ]
[-0.0125 .45455 -12 -10.0625 ]
[-0.0125 .45455 0 10.0625 ]
[-0.0125 .63636 -12 -10.0625 ]
[-0.0125 .63636 0 10.0625 ]
[-0.0125 .81818 -12 -10.0625 ]
[-0.0125 .81818 0 10.0625 ]
[-0.0125 1 -12 -10.0625 ]
[-0.0125 1 0 10.0625 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -43.25 -10.875 ]
[-0.01875 .5 -23.125 10.875 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13158 0 m
.13158 .00625 L
s
gsave
.13158 -0.0125 -82.5313 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
.26316 0 m
.26316 .00625 L
s
gsave
.26316 -0.0125 -78.5313 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.39474 0 m
.39474 .00625 L
s
gsave
.39474 -0.0125 -82.5313 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.52632 0 m
.52632 .00625 L
s
gsave
.52632 -0.0125 -72.5625 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.65789 0 m
.65789 .00625 L
s
gsave
.65789 -0.0125 -82.5313 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.78947 0 m
.78947 .00625 L
s
gsave
.78947 -0.0125 -78.5313 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.92105 0 m
.92105 .00625 L
s
gsave
.92105 -0.0125 -82.5313 -24.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.02632 0 m
.02632 .00375 L
s
.05263 0 m
.05263 .00375 L
s
.07895 0 m
.07895 .00375 L
s
.10526 0 m
.10526 .00375 L
s
.15789 0 m
.15789 .00375 L
s
.18421 0 m
.18421 .00375 L
s
.21053 0 m
.21053 .00375 L
s
.23684 0 m
.23684 .00375 L
s
.28947 0 m
.28947 .00375 L
s
.31579 0 m
.31579 .00375 L
s
.34211 0 m
.34211 .00375 L
s
.36842 0 m
.36842 .00375 L
s
.42105 0 m
.42105 .00375 L
s
.44737 0 m
.44737 .00375 L
s
.47368 0 m
.47368 .00375 L
s
.5 0 m
.5 .00375 L
s
.55263 0 m
.55263 .00375 L
s
.57895 0 m
.57895 .00375 L
s
.60526 0 m
.60526 .00375 L
s
.63158 0 m
.63158 .00375 L
s
.68421 0 m
.68421 .00375 L
s
.71053 0 m
.71053 .00375 L
s
.73684 0 m
.73684 .00375 L
s
.76316 0 m
.76316 .00375 L
s
.81579 0 m
.81579 .00375 L
s
.84211 0 m
.84211 .00375 L
s
.86842 0 m
.86842 .00375 L
s
.89474 0 m
.89474 .00375 L
s
.94737 0 m
.94737 .00375 L
s
.97368 0 m
.97368 .00375 L
s
1 0 m
1 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -71.875 -44.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
74.500 21.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
80.750 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .09091 m
.00625 .09091 L
s
gsave
-0.0125 .09091 -84.125 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .27273 m
.00625 .27273 L
s
gsave
-0.0125 .27273 -84.125 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.125 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .45455 m
.00625 .45455 L
s
gsave
-0.0125 .45455 -73 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .63636 m
.00625 .63636 L
s
gsave
-0.0125 .63636 -73 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .81818 m
.00625 .81818 L
s
gsave
-0.0125 .81818 -73 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 1 m
.00625 1 L
s
gsave
-0.0125 1 -73 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .13636 m
.00375 .13636 L
s
0 .18182 m
.00375 .18182 L
s
0 .22727 m
.00375 .22727 L
s
0 .31818 m
.00375 .31818 L
s
0 .36364 m
.00375 .36364 L
s
0 .40909 m
.00375 .40909 L
s
0 .5 m
.00375 .5 L
s
0 .54545 m
.00375 .54545 L
s
0 .59091 m
.00375 .59091 L
s
0 .68182 m
.00375 .68182 L
s
0 .72727 m
.00375 .72727 L
s
0 .77273 m
.00375 .77273 L
s
0 .86364 m
.00375 .86364 L
s
0 .90909 m
.00375 .90909 L
s
0 .95455 m
.00375 .95455 L
s
0 .04545 m
.00375 .04545 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -105.063 -14.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
71.875 14.0625 translate
90 rotate
-71.875 -14.0625 translate
0 28.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
74.500 21.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
80.750 19.313 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.13158 .99375 m
.13158 1 L
s
.26316 .99375 m
.26316 1 L
s
.39474 .99375 m
.39474 1 L
s
.52632 .99375 m
.52632 1 L
s
.65789 .99375 m
.65789 1 L
s
.78947 .99375 m
.78947 1 L
s
.92105 .99375 m
.92105 1 L
s
.125 Mabswid
.02632 .99625 m
.02632 1 L
s
.05263 .99625 m
.05263 1 L
s
.07895 .99625 m
.07895 1 L
s
.10526 .99625 m
.10526 1 L
s
.15789 .99625 m
.15789 1 L
s
.18421 .99625 m
.18421 1 L
s
.21053 .99625 m
.21053 1 L
s
.23684 .99625 m
.23684 1 L
s
.28947 .99625 m
.28947 1 L
s
.31579 .99625 m
.31579 1 L
s
.34211 .99625 m
.34211 1 L
s
.36842 .99625 m
.36842 1 L
s
.42105 .99625 m
.42105 1 L
s
.44737 .99625 m
.44737 1 L
s
.47368 .99625 m
.47368 1 L
s
.5 .99625 m
.5 1 L
s
.55263 .99625 m
.55263 1 L
s
.57895 .99625 m
.57895 1 L
s
.60526 .99625 m
.60526 1 L
s
.63158 .99625 m
.63158 1 L
s
.68421 .99625 m
.68421 1 L
s
.71053 .99625 m
.71053 1 L
s
.73684 .99625 m
.73684 1 L
s
.76316 .99625 m
.76316 1 L
s
.81579 .99625 m
.81579 1 L
s
.84211 .99625 m
.84211 1 L
s
.86842 .99625 m
.86842 1 L
s
.89474 .99625 m
.89474 1 L
s
.94737 .99625 m
.94737 1 L
s
.97368 .99625 m
.97368 1 L
s
1 .99625 m
1 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .09091 m
1 .09091 L
s
.99375 .27273 m
1 .27273 L
s
.99375 .45455 m
1 .45455 L
s
.99375 .63636 m
1 .63636 L
s
.99375 .81818 m
1 .81818 L
s
.125 Mabswid
.99625 .13636 m
1 .13636 L
s
.99625 .18182 m
1 .18182 L
s
.99625 .22727 m
1 .22727 L
s
.99625 .31818 m
1 .31818 L
s
.99625 .36364 m
1 .36364 L
s
.99625 .40909 m
1 .40909 L
s
.99625 .5 m
1 .5 L
s
.99625 .54545 m
1 .54545 L
s
.99625 .59091 m
1 .59091 L
s
.99625 .68182 m
1 .68182 L
s
.99625 .72727 m
1 .72727 L
s
.99625 .77273 m
1 .77273 L
s
.99625 .86364 m
1 .86364 L
s
.99625 .90909 m
1 .90909 L
s
.99625 .95455 m
1 .95455 L
s
.99625 .04545 m
1 .04545 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.759 .25812 m
.77562 .25592 L
.77972 .26077 L
.77792 .27751 L
.77562 .2826 L
.77187 .29426 L
.76149 .311 L
.759 .31577 L
.7516 .32775 L
.74238 .34214 L
.74041 .3445 L
.72863 .36124 L
.72576 .36534 L
.71661 .37799 L
.70914 .38809 L
.70404 .39474 L
.69252 .40955 L
.69097 .41148 L
.67761 .42823 L
.6759 .43036 L
.66405 .44498 L
.65928 .45078 L
.65018 .46172 L
.64266 .47064 L
.636 .47847 L
.62604 .49002 L
.62153 .49522 L
.60942 .50898 L
.60678 .51196 L
.5928 .52755 L
.59176 .52871 L
.57651 .54545 L
.57618 .54581 L
.56107 .5622 L
.55956 .56382 L
.54538 .57895 L
.54294 .58152 L
.52943 .59569 L
.52632 .59892 L
.51322 .61244 L
.5097 .61603 L
.49673 .62919 L
.49307 .63285 L
.47996 .64593 L
.47645 .64938 L
.46288 .66268 L
.45983 .66561 L
.44546 .67943 L
.44321 .68154 L
.42766 .69617 L
Mistroke
.42659 .69715 L
.40997 .71246 L
.4095 .71292 L
.39335 .7275 L
.39106 .72967 L
.37673 .74213 L
.37204 .74641 L
.36011 .75629 L
.35214 .76316 L
.34349 .76988 L
.33085 .7799 L
.32687 .78275 L
.31025 .7952 L
.30762 .79665 L
.29363 .80684 L
.28059 .8134 L
.27701 .81548 L
.26039 .82039 L
.25221 .8134 L
.25514 .79665 L
.26039 .78723 L
.26299 .7799 L
.27382 .76316 L
.27701 .75755 L
.28447 .74641 L
.29363 .73275 L
.29615 .72967 L
.30843 .71292 L
.31025 .71041 L
.3209 .69617 L
.32687 .68831 L
.33381 .67943 L
.34349 .66715 L
.3471 .66268 L
.36011 .6467 L
.36075 .64593 L
.37456 .62919 L
.37673 .62658 L
.38859 .61244 L
.39335 .60683 L
.40287 .59569 L
.40997 .58747 L
.41738 .57895 L
.42659 .56845 L
.43211 .5622 L
.44321 .54975 L
.44706 .54545 L
.45983 .53134 L
.46222 .52871 L
.47645 .51321 L
Mistroke
.47759 .51196 L
.49307 .49533 L
.49318 .49522 L
.50895 .47847 L
.5097 .47768 L
.52494 .46172 L
.52632 .46029 L
.54116 .44498 L
.54294 .44317 L
.55764 .42823 L
.55956 .4263 L
.57439 .41148 L
.57618 .40972 L
.59144 .39474 L
.5928 .39343 L
.60885 .37799 L
.60942 .37745 L
.62604 .36178 L
.62659 .36124 L
.64266 .34646 L
.6447 .3445 L
.65928 .33153 L
.66334 .32775 L
.6759 .31709 L
.68276 .311 L
.69252 .30324 L
.70345 .29426 L
.70914 .29014 L
.72576 .27795 L
.72651 .27751 L
.74238 .26642 L
.75391 .26077 L
.759 .25812 L
Mfstroke
.92382 .06355 m
.94901 .07895 L
.94395 .10526 L
.93456 .13158 L
.92382 .14892 L
.92155 .15789 L
.90426 .18421 L
.89197 .2034 L
.88749 .21053 L
.86888 .23684 L
.86011 .24921 L
.85059 .26316 L
.83032 .28947 L
.82825 .29221 L
.81078 .31579 L
.7964 .33388 L
.79018 .34211 L
.76864 .36842 L
.76454 .37341 L
.7474 .39474 L
.73269 .41206 L
.72538 .42105 L
.70247 .44737 L
.70083 .44925 L
.67989 .47368 L
.66898 .4859 L
.65678 .5 L
.63712 .5215 L
.63295 .52632 L
.60867 .55263 L
.60526 .55627 L
.58448 .57895 L
.57341 .59054 L
.55982 .60526 L
.54155 .62402 L
.53459 .63158 L
.5097 .65671 L
.50862 .65789 L
.48262 .68421 L
.47784 .68891 L
.45638 .71053 L
.44598 .72052 L
.42967 .73684 L
.41413 .75144 L
.40243 .76316 L
.38227 .78165 L
.37456 .78947 L
.35042 .81112 L
.34598 .81579 L
.31856 .83979 L
Mistroke
.31655 .84211 L
.2867 .8676 L
.28615 .86842 L
.25485 .89448 L
.25451 .89474 L
.22299 .92032 L
.22193 .92105 L
.19114 .94495 L
.18724 .94737 L
.15928 .96803 L
.14857 .97368 L
.12742 .9859 L
.09557 .99763 L
.08189 .97368 L
.0915 .94737 L
.09557 .94057 L
.10317 .92105 L
.12224 .89474 L
.12742 .88648 L
.13909 .86842 L
.15871 .84211 L
.15928 .84132 L
.17759 .81579 L
.19114 .79804 L
.19756 .78947 L
.21841 .76316 L
.22299 .75738 L
.23914 .73684 L
.25485 .71769 L
.26059 .71053 L
.28254 .68421 L
.2867 .67925 L
.30448 .65789 L
.31856 .64148 L
.32689 .63158 L
.34988 .60526 L
.35042 .60465 L
.37276 .57895 L
.38227 .56827 L
.396 .55263 L
.41413 .53258 L
.41966 .52632 L
.4437 .5 L
.44598 .49752 L
.46775 .47368 L
.47784 .4629 L
.49213 .44737 L
.5097 .42886 L
.51691 .42105 L
.54155 .39543 L
Mistroke
.54219 .39474 L
.56754 .36842 L
.57341 .36247 L
.59319 .34211 L
.60526 .33009 L
.61925 .31579 L
.63712 .29835 L
.64581 .28947 L
.66898 .2673 L
.67299 .26316 L
.70083 .23703 L
.701 .23684 L
.72928 .21053 L
.73269 .20751 L
.75834 .18421 L
.76454 .17897 L
.78844 .15789 L
.7964 .15161 L
.82006 .13158 L
.82825 .12575 L
.85447 .10526 L
.86011 .10197 L
.89197 .08084 L
.8962 .07895 L
.92382 .06355 L
Mfstroke
0 0 1 r
.51703 .54161 m
matrix currentmatrix
0.0105263 0.00909091 scale
49.1179 59.5771 1 0 365.73 arc
setmatrix F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00Z@3oool0103o_g@000000000
B02Lgomc0?ooo`00Z03oool01P3ookl0M01d0;ooo`3ookl0M4RL0=ooog80oooo002N0?ooo`070?oo
_`1d07@0_ooo0?ooo`3ookl0M01d0;ooo`030?ooo`060?noM000M;l0oooo0?ooo`2oM4P0W=ooLP3o
ool009h0oooo00L0okmd00000018W=l0oooo0?noM0000000M;oo00<0oooo00H0gia804RLg`3oool0
oooo0=nLB01d_omb0?ooo`00WP3oool0202oM00007Bo0;mdM02oool0_g@0001dW02LM9`0gooo0P3o
ool01P3OW4P0B9cO0?ooo`3oool0gia807Boog80oooo002M0?ooo`090?oOW01804P0W=oo0?noM01d
_kl0M01809cOo`3OW7@0W=oo0080oooo00H0okmd001d_`3oool0oooo0;md001d_omb0?ooo`00W@3o
ool02@3OW4P004RL0=ooo`3ooml0W4P0001d_`3oool0oono07Ad_`020?ooo`060?oo_`1d07@0_ooo
0?oo_`1d07@0_oooLP3oool009`0oooo00L0oooO09a8001d_ol0oooo0?oog`2LB000M;oo0080oooo
00P0_gAd0;ooo`3oool0oooo0?oOW0180000001809cOog<0oooo002K0?ooo`0=0?oog`2LB0000000
0000M02ookl0M0000000000004P0W=oo0?noM000000004RL0=ooo`1h0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00B03oool02`3ookl0M000000000000000001809cOo`3oool0
oooO09a80000B9`0gooo0080oooo00<0oono07A8W03Oool00`3oool01P3ogi`0B000000000000000
04RL0=ooo`X0oooo00d0oono07@00000000000000000B02Lgol0oooo0?oog`2LB00004RL0=ooo`3o
gi`0B0000080000000<004RL0=ooo`3oool0203oool0303ookl0M000000000000000001809cOo`3o
ool0oooO09a80000B9`0gooo0=nLB0D0000000@007Bo0?ooo`3ogi`0B0000P0000000`00B9`0gooo
0?ooo`0?0?ooo`060?oo_`1d000000000000000004P0W=oo403oool0103OW4P000000000001d_ol2
0?ooo`040?oog`2LB00004RL0=ooo`80oooo00<0oono07A8W03Oool00`3oool01P3ogi`0B0000000
0000000004RL0=ooo`/0oooo00@0gia8000000000000M;oo0P3oool01P3ooml0W4P00018W03Oool0
omnL04P00080000000<004RL0=ooo`3oool02@3oool0103OW4P000000000001d_ol20?ooo`050?oo
g`2LB00004RL0=ooo`3OW4P01@0000001000M;l0oooo0?oOW0180002000000030018W03Oool0oooo
00H0oooo001:0?ooo`030;md0000B9`0gooo00T0oooo00<0_gA809cOo`3oool01P3oool00`3ogi`0
B4RL0=ooo`0;0?ooo`030;md0000B9`0gooo00X0oooo00<0omnL04Q8W03Oool02P3oool00`2oM000
04RL0=ooo`070?ooo`030?noM000000000000080000000<0001d0;ooo`3oool00`3oool00`3ogi`0
B4RL0=ooo`0A0?ooo`030;md0000B9`0gooo0100oooo00H0okmd0018W03Oool0oono07@0001d_ol8
0?ooo`030;mdB02Lgol0oooo00H0oooo00<0omnL04Q8W03Oool02@3oool01P3o_g@004RL0=ooo`3o
okl0M00007Boo`T0oooo00<0omnL04Q8W03Oool0203oool01P3o_g@004RL0=ooo`3ookl0M00007Bo
o`H0oooo00<0okmd0000000000000P0000000`0007@0_ooo0?ooo`030?ooo`030?oOW018B9`0gooo
00H0oooo001:0?ooo`030=nLB000B9`0gooo00T0oooo00<0okmd04RLg`3oool01`3oool00`3o_g@0
M;oo0?ooo`0:0?ooo`030=nLB000B9`0gooo00/0oooo00<0okmd07Boo`3oool02@3oool00`3OW4P0
04RL0=ooo`080?ooo`060?noM018W=l0oooo0?ooo`3ogi`0W;oo1@3oool00`3o_g@0M;oo0?ooo`0@
0?ooo`030=nLB000B9`0gooo00l0oooo00<0oooO09a8001d_ol00P3oool00`3OW4P004RL0=ooo`07
0?ooo`030?noM018W=l0oooo00L0oooo00<0okmd07Boo`3oool01`3oool00`3ooml0W4P007Boo`02
0?ooo`030=nLB000B9`0gooo00T0oooo00<0okmd07Boo`3oool01P3oool00`3ooml0W4P007Boo`02
0?ooo`030=nLB000B9`0gooo00H0oooo00H0okmd04RLg`3oool0oooo0?oOW02L_ol50?ooo`030?no
M01d_ol0oooo00D0oooo001:0?ooo`030=nLB000B9`0gooo00T0oooo00<0oono07A8W03Oool01`3o
ool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB000B9`0gooo00/0oooo00<0okmd001d_`3oool02@3o
ool00`3OW4P004RL0=ooo`090?ooo`030=nLB01d_ol0oooo00L0oooo00<0okmd001d_`3oool0403o
ool00`3OW4P004RL0=ooo`0?0?ooo`030?oOW01804P0W=oo0080oooo00<0omnL04P0B02Lgol01`3o
ool00`3ookl0M4RL0=ooo`070?ooo`030?noM000M;l0oooo00L0oooo00<0omnL04P0B02Lgol00P3o
ool00`3ogi`0B01809cOo`090?ooo`030?noM000M;l0oooo00H0oooo00<0omnL04P0B02Lgol00P3o
ool00`3ogi`0B01809cOo`070?ooo`030=nLB01d_ol0oooo00L0oooo00<0okmd001d_`3oool01@3o
ool003`0oooo00<0oono07@0000000001P0000000`1d_ol0oooo0?ooo`020?ooo`030=nLB000B9`0
gooo00X0oooo00<0_gA809cOo`3oool0103oool00`3ookl0M000000000060000000307Boo`3oool0
oooo00<0oooo00<0gia80018W03Oool02@3oool00`3ookl0M000000000060000000307Boo`3oool0
oooo0080oooo00<0gia80018W03Oool02P3oool00`2oM4P0W=oo0?ooo`060?ooo`030;md0000M;l0
oooo0080oooo00<0oono07@0000000001P0000000`1d_ol0oooo0?ooo`020?ooo`030=nLB000B9`0
gooo00@0oooo00<0oono07@0000000001P0000001@1d_ol0oooo0?noM00007@0_ooo0080oooo00<0
omnL04P0001d_ol0203oool00`2oM4P0W=oo0?ooo`040?ooo`030?oo_`1d0000000000H0000000H0
M;oo0?ooo`3oool0okmd0000M02oool20?ooo`030?oOW0180000M;oo00L0oooo00<0oono07@00000
00001P0000001@1d_ol0oooo0?noM00007@0_ooo0080oooo00<0omnL04P0001d_ol0203oool00`2o
M4P0W=oo0?ooo`060?ooo`030;md0000M;l0oooo00D0oooo001:0?ooo`030=nLB000B9`0gooo00X0
oooo00<0okmd04RLg`3oool0103oool0103ooml0W4P00000001d_ol;0?ooo`030=nLB000B9`0gooo
00T0oooo00@0oooO09a800000000M;oo2P3oool00`3OW4P004RL0=ooo`0:0?ooo`030?oOW018B9`0
gooo00@0oooo00@0oooO09a800000000M;oo4@3oool00`3OW4P004RL0=ooo`0?0?ooo`030?noM000
07@0_ooo0080oooo00<0oono07@0001d_ol0203oool00`3o_g@0B9cO0?ooo`040?ooo`040?oog`2L
B000000007Boo`P0oooo00<0okmd0000M02oool00P3oool00`3ookl0M00007Boo`070?ooo`040?oo
g`2LB000000007Boo`L0oooo00<0okmd0000M02oool00P3oool00`3ookl0M00007Boo`080?ooo`03
0?oOW018B9`0gooo00@0oooo00@0oooO09a800000000M;oo1P3oool004X0oooo00<0gia80018W03O
ool02P3oool01P3ookl0M4RL0=ooo`3oool0oooO09a800<0000000<007Bo0?ooo`3oool02P3oool0
0`3OW4P004RL0=ooo`060?ooo`030?oog`2LB00000000080000000<007Bo0?ooo`3oool02@3oool0
0`3OW4P004RL0=ooo`0:0?ooo`060?oog`2LB000M;oo0?ooo`3ooml0W4P00`0000000`00M;l0oooo
0?ooo`0@0?ooo`030=nLB000B9`0gooo00l0oooo00<0okmd0000M02oool00P3oool00`3ookl0M000
07Boo`080?ooo`060?oo_`1dB9`0gooo0?ooo`3ooml0W4P00`0000000`00M;l0oooo0?ooo`070?oo
o`030?noM00007@0_ooo0080oooo00<0oono07@0001d_ol0103oool00`3ooml0W4P0000000020000
0003001d_`3oool0oooo00H0oooo00<0okmd0000M02oool00P3oool00`3ookl0M00007Boo`080?oo
o`060?oog`2LB000M;oo0?ooo`3ooml0W4P00`0000000`00M;l0oooo0?ooo`050?ooo`00BP3oool0
0`3OW4P004RL0=ooo`0;0?ooo`050;mdB02Lgol0oooo0?ooo`3o_g@00P0000000`1d_ol0oooo0?oo
o`0;0?ooo`030=nLB000B9`0gooo00L0oooo00@0okmd000000000000M;oo303oool00`3OW4P004RL
0=ooo`0;0?ooo`050;md0000M;l0oooo0?ooo`3o_g@00P0000000`1d_ol0oooo0?ooo`0A0?ooo`03
0=nLB000B9`0gooo00l0oooo00<0omnL04P0B02Lgol00P3oool00`3ogi`0B01809cOo`090?ooo`05
0;mdB02Lgol0oooo0?ooo`3o_g@00P0000000`1d_ol0oooo0?ooo`080?ooo`030?oOW01804P0W=oo
0080oooo00<0omnL04P0B02Lgol01@3oool0103o_g@000000000001d_ol90?ooo`030?oOW01804P0
W=oo0080oooo00<0omnL04P0B02Lgol02@3oool01@2oM00007Bo0?ooo`3oool0okmd0080000000<0
M;oo0?ooo`3oool01P3oool004X0oooo00<0gia80018W03Oool01P3oool00`3o_kl0_ooo0?ooo`02
0?ooo`060?noM018W=l0oooo0?ooo`3ookl0M7Bo3`3oool00`3OW4P004RL0=ooo`070?ooo`030?oo
_`1dM;l0oooo00d0oooo00<0gia80018W03Oool01P3oool01`3o_i`0W=oo0?ooo`3oool0oooO09a8
0000M;l00P3oool00`3ookl0M7Bo0?ooo`0D0?ooo`030=nLB000B9`0gooo00l0oooo00<0oooO09a8
001d_ol00P3oool00`3o_g@004RL0=ooo`040?ooo`030?no_`2oool0oooo0080oooo00H0okmd04RL
g`3oool0oooo0?oo_`1dM;l<0?ooo`030?oog`2LB000M;oo0080oooo00<0okmd0018W03Oool01@3o
ool00`3ookl0M7Bo0?ooo`0:0?ooo`030?oog`2LB000M;oo0080oooo00<0okmd0018W03Oool0103o
ool01`3o_i`0W=oo0?ooo`3oool0oooO09a80000M;l00P3oool00`3ookl0M7Bo0?ooo`090?ooo`00
B03oool01@3ookl0M00000000000B9`0gooo00H0oooo00<0oono07@0000000000`0000001@00B9`0
gooo0?ooo`3oool0gia800<0000000<0M;oo0?ooo`3oool01`3oool01@3ookl0M00000000000B9`0
gooo00P0oooo00D0gia8000000000000000007Boo`080?ooo`050?oo_`1d000000000018W03Oool0
1P3oool01`3ooml0W4Qd0;ooo`3oool0gia80000001d_ol00`3oool01@3OW4P00000000000000000
M;oo00l0oooo00D0oono07@00000000004RL0=ooo`0@0?ooo`060?noM00007@0_ooo0?oo_`1d0000
M;oo1@3oool00`3ookl0M00000000003000000050018W03Oool0oooo0?ooo`3OW4P00`0000000`1d
_ol0oooo0?ooo`070?ooo`060?noM00007@0_ooo0?oo_`1d0000M;oo1`3oool01@3OW4P000000000
00000000M;oo00P0oooo00H0okmd0000M02oool0oono07@0001d_ol50?ooo`070?oog`2LB7@0_ooo
0?ooo`3OW4P0000007Boo`030?ooo`050=nLB000000000000000001d_ol01P3oool004T0oooo00@0
oooO09a80000B9`0gooo1`3oool00`3OW4P0000000000002000000060000B02Lgol0oooo0?ooo`3o
gi`0B0000P0000000`00M;l0oooo0?ooo`080?ooo`040?oog`2LB00004RL0=ooo`P0oooo00D0omnL
04P0000000000000001d_`090?ooo`040?oog`2LB00004RL0=ooo`L0oooo00D0oono07@000000000
000007Boo`040?ooo`050?oOW0180000000000000000M;l0403oool0103ooml0W4P00018W03OoolA
0?ooo`040=nLB0000000000007Boo`L0oooo00<0gia80000000000000P0000001P0004P0W=oo0?oo
o`3oool0omnL04P00080000000<007Bo0?ooo`3oool0203oool0103OW4P000000000001d_ol80?oo
o`050?oOW0180000000000000000M;l02@3oool0103OW4P000000000001d_ol70?ooo`050?oo_`1d
000000000000001d_ol0103oool01@3ogi`0B00000000000000007Bo00H0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000`0?ooon/000001@3oool00300oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo0>L0
oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0i`3oool00`000000oooo
0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo00<0oooo000`
0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?oo
o`3oool0i`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`3W0?ooo`03
0000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool0
0`3oool00300oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`030?ooo`00<03oool2
00000>L0oooo0P0000050?ooo`00<03oool00`000000oooo0?ooo`3W0?ooo`030000003oool0oooo
00<0oooo000`0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool00`3oool00300oooo
00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?oo
o`3W0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`3C0?oo
o`80000000<0oooo0000000000003`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`3OW4P0
04RL0=ooo`050?ooo`030000003oool0oooo0=40oooo0P0000050?ooo`8000003@3oool00`000000
oooo0?ooo`030?ooo`00:03oool00`3OW4P004RL0=ooo`050?ooo`030000003oool0oooo0<l0oooo
0P0000090?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`3OW4P004RL0=oo
o`050?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo000T0?ooo`030;md00000000000000@0000000<0M;oo
0?ooo`3oool00P3oool00`000000oooo0?ooo`3<0?ooo`8000003@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo000H0?ooo`030?oo_`1d0000000000H0000000D0M;oo0?oo
o`3oool0omnL09boo`020?ooo`030=nLB000B9`0gooo00D0oooo0`00003;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool02@3oool2000000D0oooo000U0?ooo`060;mdM02oool0oooo
0=nLB000B9`0gooo1@3oool00`000000oooo0?ooo`390?ooo`8000003`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo000U0?ooo`060?oo_`1dM;l0oooo0=nLB000B9`0gooo
1@3oool00`000000oooo0?ooo`370?ooo`8000004@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo000V0?ooo`050?noM01d_ol0gia80018W03Oool01@3oool00`000000oooo
0?ooo`350?ooo`8000004`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
000W0?ooo`040;mdM02LW4P004RL0=ooo`D0oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool002L0oooo00@0
oono07@00000B9`0gooo1@3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00:03oool00`3o_g@004RL0=oo
o`050?ooo`030000003oool0oooo0<40oooo0P00000F0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00`3oool00300oooo00<000000?ooo`3oool0_@3oool2000001T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`2l0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00<03o
ool200000;`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`8000001@3o
ool00300oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00300
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0]`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00300oooo00<0
00000?ooo`3oool0]P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00`3oool00300oooo00<000000?ooo`3oool0/P3oool2000001l0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`00<03o
ool200000;40oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`8000001@3o
ool00300oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0[P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00300
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0Z`3oool200000280oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`030?ooo`00<03oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`2X0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?oo
o`00<03oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`00<03o
ool00`000000oooo0?ooo`2T0?ooo`8000009@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00<0oooo000`0?ooo`800000Y03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo01T0oooo0P0000050?ooo`00<03oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000
oooo0?ooo`2Q0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`030?ooo`00<03oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`00903oool00`3OW4P00000000000030000
0003001d_`3oool0oooo00<0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0B0?oo
o`8000004@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo000U0?ooo`03
0?noM000000000000080000000<0001d0;ooo`3oool00`3oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo0100oooo0`0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool00`3oool002H0oooo00H0okmd04RLg`3oool0oooo0?oOW02L_ol40?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool03`3oool2000000D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00<0oooo000W0?ooo`03
0=nLB01d_ol0oooo00H0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0>0?ooo`80
00001`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool00`3oool001P0oooo00<0oono07@0000000001P0000000`1d_ol0oooo0?ooo`040?ooo`030;md
B02Lgol0oooo00D0oooo0`00002I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0240oooo0P0000050?ooo`00:03o
ool00`3ogi`0B4RL0=ooo`050?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool03@3o
ool2000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00<0oooo000X0?ooo`030?oog`2LB000M;oo00D0oooo00<000000?ooo`3oool0UP3oool2
000000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00`3oool002T0oooo00<0_g@0001d_`3oool0103oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo00d0oooo0P00000<0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`00903oool01`3o_i`0
W=oo0?ooo`3oool0oooO09a80000M;l01@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo00`0oooo0P00000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`030?ooo`00903oool01`3ooml0W4Qd0;ooo`3oool0gia80000001d_ol01@3o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3o
ool002D0oooo00D0oono07@000000000000007Boo`060?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo000`0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool02`3oool200000100oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`00<03o
ool2000008h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0:@3oool2000000D0oooo000`0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool02P3oool2000001<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool00300oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo
000`0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool02@3oool2000001@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo000`
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C
0?ooo`8000002P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00<0oooo000`0?oo
o`030000003oool0oooo08L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`030?oo
o`00<03oool00`000000oooo0?ooo`250?ooo`800000303oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`00
<03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`030?ooo`00<03o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool00`3o
ool00300oooo0P0000230?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0340oooo0P0000050?ooo`00<03oool00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool00`3oool00300
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00<0
oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0203oool2000001T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00<0oooo000`0?ooo`800000NP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0i0?ooo`8000001@3oool00300oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo00P0oooo0P00000J0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?oo
o`1e0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool00`3oool00300oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo0P000008
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00<0oooo000V0?ooo`04
0=nLB0000000000007Boo`H0oooo00<000000?ooo`3oool0LP3oool2000000T0oooo0P00000K0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`030?oo
o`009@3oool01P3o_g@004RL0=ooo`3ookl0M00007Boo`D0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00<0oooo000T0?ooo`030?oog`2LB000M;oo
0080oooo00<0gia80018W03Oool0103oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool00`3oool002@0oooo00<0omnL04P0B02Lgol00P3oool00`3ogi`0
B01809cOo`040?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`030?ooo`00903oool00`3o_g@0001d0;ooo`020?ooo`030?oOW0180000M;oo00@0oooo
0`00001^0?ooo`030000003oool0oooo00P0oooo0P00000L0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0@`3oool2000000D0oooo000T0?ooo`030?noM00007@0_ooo0080oooo00<0
oono07@0001d_ol0103oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool00`3oool002@0oooo00<0okmd0000M02oool00P3oool00`3ookl0M00007Boo`04
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`03
0?ooo`00203oool00`3o_g@0M;oo0?ooo`0I0?ooo`030?oOW01804P0W=oo0080oooo00<0omnL04P0
B02Lgol0103oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool00`3oool000P0oooo00D0okmd00000000000004RL0=ooo`0G0?ooo`030?oog`2LB000M;oo
0080oooo00<0okmd0018W03Oool0103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool00`3oool000P0oooo00@0oknL09cOo`3ogi`0B0000`0000000`18
W=l0oooo0?ooo`0C0?ooo`060?noM00007@0_ooo0?oo_`1d0000M;oo1@3oool00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool00`3oool000d0oooo00@0okmd
0000000007@0_ooo5@3oool0103OW4P000000000001d_ol60?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`030?ooo`00203oool01P3o_g@0M;oo0?oo
o`3o_g@00000001d_b80oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo00<0oooo00080?ooo`040?noM00000000000001d_b@0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00<0oooo00080?ooo`030?no
M01d_ol0_g@000@0000000<0B9cO0?ooo`3oool07P3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool00`3oool000P0oooo00<0oknL09cOo`3oool00P3o
ool0102oM00000000000M02ooolO0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`030?ooo`00203oool00`3o_i`0W=oo0;md00020000000307Boo`3o
ool0oooo0200oooo0P00001V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04`0oooo0P0000050?ooo`00203oool0
0`3o_g@0000007Boo`0U0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`030?ooo`00203oool00`3o_i`0W=oo0?ooo`0U0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`800000203oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`030?ooo`002`3oool00`3ookl0M7Bo
0?ooo`040?ooo`030=nLW02oool0oooo01/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo00<0oooo000;0?ooo`030=nLB0000000000000@0000000<0
001d0;ooo`3oool06`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00H0oooo0P00
000M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`030?ooo`004P3oool00`3OW9`0_ooo0?ooo`0K0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`1N0?oo
o`8000002@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`1M0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool30000o`h0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`D0003o
303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
0`3oool00300oooo0P00001M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool50000o`/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1E0?ooo`8000001@3o
ool00300oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00`0oooo10000?l;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0F@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`800000203oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00<0oooo000`0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`030?ooo`00
<03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
0`3oool00300oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo00<0oooo000`0?ooo`800000D`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`8000001@3oool0
0300oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo
00<0oooo000`0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`030?ooo`00903oool00`3OW4P00000000000030000
0003001d_`3oool0oooo00<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo00<0oooo000U0?ooo`030?noM000000000000080000000<0001d0;ooo`3o
ool00`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool00`3oool002H0oooo00H0okmd04RLg`3oool0oooo0?oOW02L_ol40?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`030?ooo`009`3oool00`3OW4P0
M;oo0?ooo`060?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo0P00001[0?ooo`030000003oool0oooo00<0
oooo000X0?ooo`030;mdB02Lgol0oooo00D0oooo0`0000190?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06X0oooo
0P0000050?ooo`00:03oool00`3ogi`0B4RL0=ooo`050?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0K03oool00`000000oooo0?ooo`030?ooo`00:03oool00`3ooml0W4P007Boo`05
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`03
0?ooo`00:@3oool00`2oM00007Bo0?ooo`040?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0H0?ooo`800000203oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00<0oooo000T0?ooo`070?noW02Lgol0oooo0?ooo`3ooml0W4P0001d_`05
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`03
0?ooo`00903oool01`3ooml0W4Qd0;ooo`3oool0gia80000001d_ol01@3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`060?ooo`800000L@3oool00`000000oooo0?ooo`030?ooo`009@3oool01@3ookl0M00000000000
0000M;oo00H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00<0oooo000`0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0G0?ooo`8000001`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0
oooo00<0oooo000`0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00P0
oooo0P00000I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool00`3oool00300oooo0P0000100?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07@0oooo0P00
00050?ooo`00<03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01D0oooo0P0000090?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool00`3oool00300oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`080?ooo`80
00005`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool00`3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool05@3oool2000000T0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
00P0oooo0P00000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`030?ooo`00<03oool2000003P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0O`3oool2000000D0oooo000`0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool2000000X0oooo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo08<0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203o
ool2000008H0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool00`3oool00300oooo
00<000000?ooo`3oool0<03oool2000000/0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool00`3oool00300oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00<0oooo000`
0?ooo`800000<03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`2:0?ooo`8000001@3oool00300oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo0P00000:0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`030?ooo`00<03o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool00`3o
ool00300oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo0P00000;0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool00`3oool0
0300oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00T0oooo0P00000<0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool00`3oool002P0
oooo00<0gia80018W03Oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool2000000`0oooo0P00002D0?ooo`030000003oool0oooo00<0
oooo000X0?ooo`030=nLB000B9`0gooo00D0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`2D0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030=nLB000B9`0gooo00D0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0P00
000=0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool00`3oool002@0oooo00<0_g@0
000000000000100000000`1d_ol0oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`<000003P3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo00<0oooo000T0?ooo`070?oOW02L_ol0oooo0?ooo`3OW4P004RL0=oo
o`050?ooo`<000009P3oool00`000000oooo0?ooo`0@0?ooo`@00000403oool00`000000oooo0?oo
o`2F0?ooo`8000001@3oool002D0oooo00H0_gAd0;ooo`3oool0gia80018W03Oool50?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2H0?ooo`030000
003oool0oooo00<0oooo000U0?ooo`060?oo_`1dM;l0oooo0=nLB000B9`0gooo1@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0V@3oool00`000000
oooo0?ooo`030?ooo`009P3oool01@3o_g@0M;oo0=nLB000B9`0gooo00D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool00`3oool002L0oooo00@0_gAd09bLB000B9`0gooo1@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`030?ooo`00
9`3oool0103ookl0M0000018W03Oool50?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00<0oooo000X0?ooo`030?no
M000B9`0gooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0Q0?ooo`800000X03oool00`000000oooo0?ooo`030?ooo`00<03oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0X03oool0
0`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo0P00002T0?ooo`030000003oool0oooo00<0
oooo000`0?ooo`800000803oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0:<0oooo
0P0000050?ooo`00<03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`03
0?ooo`00<03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0YP3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01d0oooo0P00002Y0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2Y0?ooo`030000
003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo00<0oooo000`0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo00<0
oooo000`0?ooo`8000006@3oool00`000000oooo0?ooo`0J0?ooo`800000[`3oool2000000D0oooo
000`0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo00<0oooo000`0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool200000;@0oooo00<000000?oo
o`3oool00`3oool00300oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0;@0oooo00<000000?ooo`3oool00`3oool00300oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0
0`3oool00300oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`800000^03o
ool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`030?ooo`00<03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0
oooo0P00002l0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo00<0oooo
000`0?ooo`8000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0;`0oooo0P00
00050?ooo`00<03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo0P000030
0?ooo`030000003oool0oooo00<0oooo000`0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo00<0oooo000`0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool200000<<0oooo00<000000?ooo`3o
ool00`3oool00300oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`800000
a@3oool00`000000oooo0?ooo`030?ooo`00<03oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00X0oooo0P0000370?ooo`030000003oool0oooo00<0oooo000V0?ooo`040;md00000000
0000001d_`H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`800000b@3o
ool00`000000oooo0?ooo`030?ooo`009@3oool01P3OW4P0001d0;ooo`3oool0_g@0001d_`D0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`800000b`3oool00`000000oooo
0?ooo`030?ooo`00903oool00`3ookl0M00007Boo`020?ooo`030?oOW01804P0W=oo00@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`800000c@3oool00`000000oooo0?oo
o`030?ooo`00903oool00`3o_g@0001d0;ooo`020?ooo`030?oo_`1d0000M;oo00@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`030?ooo`00903oool00`3o_g@0001d0;ooo`020?ooo`030?noM0000000M;oo
00@0ooooj`0000050?ooo`00903oool0203o_g@0000004Q8W02oool0oooO09a8000007@0_ooom03o
ool002@0oooo00L0oono07@00018W9`0M0000000000007@0_ooo0?D0oooo000U0?ooo`030;md0000
07@0_ooo0?P0oooo000U0?ooo`030?oo_`1d000007Bo0?P0oooo000V0?ooo`040?oo_`1d0000001d
0;ooooH0oooo000X0?ooo`040=nLB0000000001d0;oooo@0oooo003o0?ooob40oooo003o0?ooob40
oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.39743, -7.03156, 0.00812788, \
0.0470562}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\<w0w1_contour_nuc_024.m\>", impwcc]\)], "Input"],

Cell[BoxData[
    \("w0w1_contour_nuc_024.m"\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ This\ fig\ requires\ the\ w0 - 
        w1\ contour\ \((file "\<snls_w0_w1_contour_om0_024.m\>"\ created\ by\ \
the\ "\<figs1_2_3_4.nb\>"\ file)\)\ *) \)], "Input",
  FontSize->18],

Cell[BoxData[
    \(\(impw = Import["\<snls_w0_w1_contour_om0_024.m\>"];\)\)], "Input"],

Cell[BoxData[
    \( (*\ Alter\ the\ style\ of\ the\ plots\ *) \)], "Input",
  FontSize->18],

Cell[BoxData[{
    \(\(impw = 
        Insert[Delete[impw, {{1, 1, 1, 1}, {1, 2, 1, 1}}], 
          GrayLevel[
            0], {{1, 1, 1, 1}, {1, 2, 1, 1}}];\)\), "\[IndentingNewLine]", 
    \(\(impwcc = 
        Insert[Delete[impwcc, {{1, 1, 1, 1}, {1, 2, 1, 1}}], 
          Dashing[{0.03,  .01}], {{1, 1, 1, 1}, {1, 2, 1, 
              1}}];\)\), "\[IndentingNewLine]", 
    \(\(impw = 
        Insert[Delete[impw, {{1, 1, 1, 2}, {1, 2, 1, 2}}], 
          Thickness[0.005], {{1, 1, 1, 2}, {1, 2, 1, 2}}];\)\), "\n", 
    \(\(impwcc = 
        Insert[Delete[impwcc, {{1, 1, 1, 2}, {1, 2, 1, 2}}], 
          Thickness[0.005], {{1, 1, 1, 2}, {1, 2, 1, 2}}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(finalall = 
        Show[impwcc, impw, 
          Graphics[{Text["\<\[Alpha] = 0\>", {\(-1.3\), 0}], 
              Text["\<\[Alpha] = 0.2\>", {\(-1\), 4}]}], 
          PlotRange \[Rule] All, 
          TextStyle -> {FontFamily \[Rule] "\<Times\>", 
              FontSize \[Rule] 30}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.06862 0.560976 0.465301 0.0855199 [
[.08691 -0.0125 -38.6875 -35.625 ]
[.08691 -0.0125 38.6875 0 ]
[.22715 -0.0125 -31.1875 -35.625 ]
[.22715 -0.0125 31.1875 0 ]
[.3674 -0.0125 -38.6875 -35.625 ]
[.3674 -0.0125 38.6875 0 ]
[.50764 -0.0125 -19.9063 -35.625 ]
[.50764 -0.0125 19.9063 0 ]
[.64788 -0.0125 -38.6875 -35.625 ]
[.64788 -0.0125 38.6875 0 ]
[.78813 -0.0125 -31.1875 -35.625 ]
[.78813 -0.0125 31.1875 0 ]
[.92837 -0.0125 -38.6875 -35.625 ]
[.92837 -0.0125 38.6875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -18.4688 -71.25 ]
[.5 -0.0125 18.4688 -35.625 ]
[-0.0125 .12322 -39.8125 -17.8125 ]
[-0.0125 .12322 0 17.8125 ]
[-0.0125 .29426 -39.8125 -17.8125 ]
[-0.0125 .29426 0 17.8125 ]
[-0.0125 .4653 -19 -17.8125 ]
[-0.0125 .4653 0 17.8125 ]
[-0.0125 .63634 -19 -17.8125 ]
[-0.0125 .63634 0 17.8125 ]
[-0.0125 .80738 -19 -17.8125 ]
[-0.0125 .80738 0 17.8125 ]
[-0.0125 .97842 -19 -17.8125 ]
[-0.0125 .97842 0 17.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -75.4375 -18.4688 ]
[-0.01875 .5 -39.8125 18.4688 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.33935 .4653 -35.5938 -17.8125 ]
[.33935 .4653 35.5938 17.8125 ]
[.50764 .80738 -46.875 -17.8125 ]
[.50764 .80738 46.875 17.8125 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08691 0 m
.08691 .00625 L
s
gsave
.08691 -0.0125 -99.6875 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
1.000 setlinewidth
grestore
.22715 0 m
.22715 .00625 L
s
gsave
.22715 -0.0125 -92.1875 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.3674 0 m
.3674 .00625 L
s
gsave
.3674 -0.0125 -99.6875 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.50764 0 m
.50764 .00625 L
s
gsave
.50764 -0.0125 -80.9063 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.64788 0 m
.64788 .00625 L
s
gsave
.64788 -0.0125 -99.6875 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.78813 0 m
.78813 .00625 L
s
gsave
.78813 -0.0125 -92.1875 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.92837 0 m
.92837 .00625 L
s
gsave
.92837 -0.0125 -99.6875 -39.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.11496 0 m
.11496 .00375 L
s
.14301 0 m
.14301 .00375 L
s
.17105 0 m
.17105 .00375 L
s
.1991 0 m
.1991 .00375 L
s
.2552 0 m
.2552 .00375 L
s
.28325 0 m
.28325 .00375 L
s
.3113 0 m
.3113 .00375 L
s
.33935 0 m
.33935 .00375 L
s
.39544 0 m
.39544 .00375 L
s
.42349 0 m
.42349 .00375 L
s
.45154 0 m
.45154 .00375 L
s
.47959 0 m
.47959 .00375 L
s
.53569 0 m
.53569 .00375 L
s
.56374 0 m
.56374 .00375 L
s
.59179 0 m
.59179 .00375 L
s
.61984 0 m
.61984 .00375 L
s
.67593 0 m
.67593 .00375 L
s
.70398 0 m
.70398 .00375 L
s
.73203 0 m
.73203 .00375 L
s
.76008 0 m
.76008 .00375 L
s
.81618 0 m
.81618 .00375 L
s
.84423 0 m
.84423 .00375 L
s
.87227 0 m
.87227 .00375 L
s
.90032 0 m
.90032 .00375 L
s
.05886 0 m
.05886 .00375 L
s
.03081 0 m
.03081 .00375 L
s
.00276 0 m
.00276 .00375 L
s
.95642 0 m
.95642 .00375 L
s
.98447 0 m
.98447 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -79.4688 -75.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
84.750 36.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 21.313 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
95.938 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12322 m
.00625 .12322 L
s
gsave
-0.0125 .12322 -100.813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .29426 m
.00625 .29426 L
s
gsave
-0.0125 .29426 -100.813 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
83.813 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .4653 m
.00625 .4653 L
s
gsave
-0.0125 .4653 -80 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .63634 m
.00625 .63634 L
s
gsave
-0.0125 .63634 -80 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .80738 m
.00625 .80738 L
s
gsave
-0.0125 .80738 -80 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .97842 m
.00625 .97842 L
s
gsave
-0.0125 .97842 -80 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .16598 m
.00375 .16598 L
s
0 .20874 m
.00375 .20874 L
s
0 .2515 m
.00375 .2515 L
s
0 .33702 m
.00375 .33702 L
s
0 .37978 m
.00375 .37978 L
s
0 .42254 m
.00375 .42254 L
s
0 .50806 m
.00375 .50806 L
s
0 .55082 m
.00375 .55082 L
s
0 .59358 m
.00375 .59358 L
s
0 .6791 m
.00375 .6791 L
s
0 .72186 m
.00375 .72186 L
s
0 .76462 m
.00375 .76462 L
s
0 .85014 m
.00375 .85014 L
s
0 .8929 m
.00375 .8929 L
s
0 .93566 m
.00375 .93566 L
s
0 .08046 m
.00375 .08046 L
s
0 .0377 m
.00375 .0377 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -137.094 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
79.4688 21.8125 translate
90 rotate
-79.4688 -21.8125 translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
84.750 36.750 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 21.313 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
95.938 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08691 .99375 m
.08691 1 L
s
.22715 .99375 m
.22715 1 L
s
.3674 .99375 m
.3674 1 L
s
.50764 .99375 m
.50764 1 L
s
.64788 .99375 m
.64788 1 L
s
.78813 .99375 m
.78813 1 L
s
.92837 .99375 m
.92837 1 L
s
.125 Mabswid
.11496 .99625 m
.11496 1 L
s
.14301 .99625 m
.14301 1 L
s
.17105 .99625 m
.17105 1 L
s
.1991 .99625 m
.1991 1 L
s
.2552 .99625 m
.2552 1 L
s
.28325 .99625 m
.28325 1 L
s
.3113 .99625 m
.3113 1 L
s
.33935 .99625 m
.33935 1 L
s
.39544 .99625 m
.39544 1 L
s
.42349 .99625 m
.42349 1 L
s
.45154 .99625 m
.45154 1 L
s
.47959 .99625 m
.47959 1 L
s
.53569 .99625 m
.53569 1 L
s
.56374 .99625 m
.56374 1 L
s
.59179 .99625 m
.59179 1 L
s
.61984 .99625 m
.61984 1 L
s
.67593 .99625 m
.67593 1 L
s
.70398 .99625 m
.70398 1 L
s
.73203 .99625 m
.73203 1 L
s
.76008 .99625 m
.76008 1 L
s
.81618 .99625 m
.81618 1 L
s
.84423 .99625 m
.84423 1 L
s
.87227 .99625 m
.87227 1 L
s
.90032 .99625 m
.90032 1 L
s
.05886 .99625 m
.05886 1 L
s
.03081 .99625 m
.03081 1 L
s
.00276 .99625 m
.00276 1 L
s
.95642 .99625 m
.95642 1 L
s
.98447 .99625 m
.98447 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .12322 m
1 .12322 L
s
.99375 .29426 m
1 .29426 L
s
.99375 .4653 m
1 .4653 L
s
.99375 .63634 m
1 .63634 L
s
.99375 .80738 m
1 .80738 L
s
.99375 .97842 m
1 .97842 L
s
.125 Mabswid
.99625 .16598 m
1 .16598 L
s
.99625 .20874 m
1 .20874 L
s
.99625 .2515 m
1 .2515 L
s
.99625 .33702 m
1 .33702 L
s
.99625 .37978 m
1 .37978 L
s
.99625 .42254 m
1 .42254 L
s
.99625 .50806 m
1 .50806 L
s
.99625 .55082 m
1 .55082 L
s
.99625 .59358 m
1 .59358 L
s
.99625 .6791 m
1 .6791 L
s
.99625 .72186 m
1 .72186 L
s
.99625 .76462 m
1 .76462 L
s
.99625 .85014 m
1 .85014 L
s
.99625 .8929 m
1 .8929 L
s
.99625 .93566 m
1 .93566 L
s
.99625 .08046 m
1 .08046 L
s
.99625 .0377 m
1 .0377 L
s
.25 Mabswid
1 0 m
1 1 L
s
.005 w
[ .03 .01 ] 0 setdash
.75565 .28052 m
.77337 .27845 L
.77773 .28301 L
.77582 .29876 L
.77337 .30355 L
.76936 .31452 L
.7583 .33027 L
.75565 .33475 L
.74776 .34602 L
.73794 .35956 L
.73583 .36178 L
.72327 .37753 L
.72022 .38139 L
.71046 .39328 L
.70251 .40278 L
.69707 .40904 L
.68479 .42298 L
.68314 .42479 L
.6689 .44055 L
.66708 .44255 L
.65445 .4563 L
.64936 .46176 L
.63966 .47205 L
.63165 .48044 L
.62455 .48781 L
.61393 .49867 L
.60912 .50356 L
.59622 .51651 L
.5934 .51931 L
.5785 .53398 L
.5774 .53507 L
.56114 .55082 L
.56079 .55116 L
.54468 .56657 L
.54307 .5681 L
.52796 .58233 L
.52536 .58475 L
.51096 .59808 L
.50764 .60112 L
.49368 .61384 L
.48993 .61721 L
.47611 .62959 L
.47221 .63303 L
.45823 .64534 L
.45449 .64858 L
.44003 .6611 L
.43678 .66386 L
.42146 .67685 L
.41906 .67884 L
.40249 .6926 L
Mistroke
.40135 .69353 L
.38363 .70793 L
.38314 .70836 L
.36592 .72207 L
.36348 .72411 L
.3482 .73584 L
.3432 .73987 L
.33049 .74916 L
.32199 .75562 L
.31277 .76194 L
.2993 .77137 L
.29506 .77405 L
.27734 .78576 L
.27454 .78713 L
.25963 .79671 L
.24574 .80288 L
.24191 .80484 L
.2242 .80946 L
.21548 .80288 L
.21861 .78713 L
.2242 .77826 L
.22698 .77137 L
.23852 .75562 L
.24191 .75034 L
.24986 .73987 L
.25963 .72701 L
.26232 .72411 L
.27541 .70836 L
.27734 .706 L
.2887 .6926 L
.29506 .68521 L
.30246 .67685 L
.31277 .6653 L
.31663 .6611 L
.33049 .64606 L
.33117 .64534 L
.34589 .62959 L
.3482 .62713 L
.36085 .61384 L
.36592 .60856 L
.37606 .59808 L
.38363 .59034 L
.39153 .58233 L
.40135 .57246 L
.40723 .56657 L
.41906 .55486 L
.42316 .55082 L
.43678 .53755 L
.43932 .53507 L
.45449 .52048 L
Mistroke
.45571 .51931 L
.47221 .50367 L
.47232 .50356 L
.48913 .48781 L
.48993 .48707 L
.50617 .47205 L
.50764 .47071 L
.52346 .4563 L
.52536 .4546 L
.54102 .44055 L
.54307 .43873 L
.55888 .42479 L
.56079 .42313 L
.57706 .40904 L
.5785 .40781 L
.5956 .39328 L
.59622 .39278 L
.61393 .37804 L
.61452 .37753 L
.63165 .36362 L
.63382 .36178 L
.64936 .34958 L
.65369 .34602 L
.66708 .336 L
.67438 .33027 L
.68479 .32297 L
.69644 .31452 L
.70251 .31065 L
.72022 .29918 L
.72101 .29876 L
.73794 .28833 L
.75023 .28301 L
.75565 .28052 L
Mfstroke
.93132 .09748 m
.95817 .11197 L
.95278 .13672 L
.94276 .16148 L
.93132 .17779 L
.9289 .18624 L
.91047 .21099 L
.89737 .22904 L
.8926 .23575 L
.87276 .2605 L
.86342 .27214 L
.85327 .28526 L
.83167 .31001 L
.82946 .31259 L
.81084 .33477 L
.79551 .35179 L
.78888 .35953 L
.76593 .38428 L
.76156 .38898 L
.74328 .40904 L
.7276 .42533 L
.71982 .43379 L
.6954 .45855 L
.69365 .46032 L
.67133 .48331 L
.65969 .4948 L
.6467 .50806 L
.62574 .52828 L
.6213 .53282 L
.59542 .55757 L
.59179 .561 L
.56963 .58233 L
.55783 .59323 L
.54335 .60708 L
.52388 .62473 L
.51646 .63184 L
.48993 .65548 L
.48877 .6566 L
.46107 .68135 L
.45597 .68577 L
.4331 .70611 L
.42202 .71551 L
.40463 .73086 L
.38806 .7446 L
.37559 .75562 L
.35411 .77302 L
.34589 .78037 L
.32016 .80074 L
.31543 .80513 L
.2862 .82771 L
Mistroke
.28406 .82989 L
.25225 .85387 L
.25166 .85464 L
.21829 .87916 L
.21793 .8794 L
.18434 .90346 L
.18321 .90415 L
.15039 .92663 L
.14623 .92891 L
.11643 .94834 L
.10502 .95366 L
.08248 .96516 L
.04853 .97619 L
.03395 .95366 L
.04419 .92891 L
.04853 .92251 L
.05663 .90415 L
.07695 .8794 L
.08248 .87163 L
.09492 .85464 L
.11583 .82989 L
.11643 .82915 L
.13595 .80513 L
.15039 .78844 L
.15724 .78037 L
.17946 .75562 L
.18434 .75019 L
.20156 .73086 L
.21829 .71285 L
.22441 .70611 L
.24781 .68135 L
.25225 .67669 L
.27119 .6566 L
.2862 .64116 L
.29508 .63184 L
.31958 .60708 L
.32016 .60651 L
.34398 .58233 L
.35411 .57228 L
.36874 .55757 L
.38806 .53871 L
.39396 .53282 L
.41958 .50806 L
.42202 .50573 L
.44521 .48331 L
.45597 .47316 L
.4712 .45855 L
.48993 .44114 L
.49761 .43379 L
.52388 .40969 L
Mistroke
.52456 .40904 L
.55158 .38428 L
.55783 .37869 L
.57892 .35953 L
.59179 .34822 L
.6067 .33477 L
.62574 .31836 L
.63501 .31001 L
.65969 .28916 L
.66398 .28526 L
.69365 .26068 L
.69383 .2605 L
.72397 .23575 L
.7276 .23291 L
.75494 .21099 L
.76156 .20606 L
.78703 .18624 L
.79551 .18032 L
.82073 .16148 L
.82946 .156 L
.8574 .13672 L
.86342 .13362 L
.89737 .11375 L
.90188 .11197 L
.93132 .09748 L
Mfstroke
0 0 1 r
.49774 .5472 m
matrix currentmatrix
0.0112195 0.00855199 scale
44.3638 63.9851 1 0 365.73 arc
setmatrix F
0 g
[ ] 0 setdash
.7658 .21848 m
.77907 .21347 L
.78969 .22195 L
.78936 .23421 L
.7834 .24647 L
.77907 .25434 L
.77679 .25874 L
.76912 .271 L
.7658 .27633 L
.76094 .28326 L
.75252 .29496 L
.75207 .29553 L
.74291 .30779 L
.73925 .31259 L
.73338 .32005 L
.72598 .32929 L
.72348 .33231 L
.71328 .34458 L
.71271 .34525 L
.7029 .35684 L
.69944 .36087 L
.69227 .3691 L
.68617 .37603 L
.68141 .38136 L
.6729 .39082 L
.67034 .39363 L
.65963 .40528 L
.65906 .40589 L
.64763 .41815 L
.64636 .4195 L
.63603 .43042 L
.63309 .4335 L
.62426 .44268 L
.61982 .44726 L
.61232 .45494 L
.60655 .46081 L
.60022 .4672 L
.59328 .47417 L
.58796 .47947 L
.58001 .48733 L
.57554 .49173 L
.56674 .50032 L
.56296 .50399 L
.55347 .51314 L
.55022 .51625 L
.5402 .5258 L
.53733 .52852 L
.52692 .5383 L
.52428 .54078 L
.51365 .55065 L
Mistroke
.51106 .55304 L
.50038 .56284 L
.49769 .5653 L
.48711 .57488 L
.48414 .57757 L
.47384 .58678 L
.47042 .58983 L
.46057 .59852 L
.45651 .60209 L
.4473 .61011 L
.44241 .61436 L
.43403 .62155 L
.4281 .62662 L
.42076 .63282 L
.41356 .63888 L
.40749 .64393 L
.39877 .65114 L
.39422 .65486 L
.3837 .66341 L
.38095 .66561 L
.36832 .67567 L
.36768 .67617 L
.35441 .68656 L
.35267 .68793 L
.34114 .69674 L
.33662 .70019 L
.32787 .70666 L
.31999 .71246 L
.3146 .71628 L
.30258 .72472 L
.30133 .72557 L
.28805 .73461 L
.28479 .73698 L
.27478 .74318 L
.2649 .74924 L
.26151 .75105 L
.24824 .75852 L
.24125 .76151 L
.23497 .76438 L
.2217 .76772 L
.21097 .76151 L
.21214 .74924 L
.21879 .73698 L
.2217 .73028 L
.22594 .72472 L
.23429 .71246 L
.23497 .71142 L
.24299 .70019 L
.24824 .69303 L
.25226 .68793 L
Mistroke
.26151 .67623 L
.26199 .67567 L
.27195 .66341 L
.27478 .65996 L
.28219 .65114 L
.28805 .64423 L
.29269 .63888 L
.30133 .62898 L
.30343 .62662 L
.31436 .61436 L
.3146 .61409 L
.32544 .60209 L
.32787 .59943 L
.33669 .58983 L
.34114 .58503 L
.3481 .57757 L
.35441 .57086 L
.35967 .5653 L
.36768 .5569 L
.37138 .55304 L
.38095 .54312 L
.38322 .54078 L
.39422 .52952 L
.39521 .52852 L
.40732 .51625 L
.40749 .51608 L
.41954 .50399 L
.42076 .50278 L
.43189 .49173 L
.43403 .48962 L
.44437 .47947 L
.4473 .47661 L
.45698 .4672 L
.46057 .46373 L
.46971 .45494 L
.47384 .45099 L
.48257 .44268 L
.48711 .43838 L
.49557 .43042 L
.50038 .42591 L
.5087 .41815 L
.51365 .41357 L
.52198 .40589 L
.52692 .40136 L
.53541 .39363 L
.5402 .38929 L
.54899 .38136 L
.55347 .37737 L
.56275 .3691 L
.56674 .36558 L
Mistroke
.57669 .35684 L
.58001 .35395 L
.59083 .34458 L
.59328 .34248 L
.6052 .33231 L
.60655 .33118 L
.61982 .32005 L
.61982 .32005 L
.63309 .3091 L
.63467 .30779 L
.64636 .29835 L
.64986 .29553 L
.65963 .28784 L
.66545 .28326 L
.6729 .27758 L
.68157 .271 L
.68617 .26762 L
.6984 .25874 L
.69944 .25801 L
.71271 .24873 L
.71577 .24647 L
.72598 .23994 L
.73494 .23421 L
.73925 .23184 L
.75252 .22444 L
.75803 .22195 L
.7658 .21848 L
Mfstroke
.93691 .03142 m
.95875 .02381 L
.97619 .03768 L
.97602 .05792 L
.96663 .07816 L
.95875 .09287 L
.95602 .09839 L
.94383 .11863 L
.93691 .12992 L
.93063 .13887 L
.91628 .1591 L
.91507 .16083 L
.90152 .17934 L
.89323 .19038 L
.88603 .19958 L
.87139 .218 L
.86989 .21981 L
.85336 .24005 L
.84955 .24467 L
.83643 .26029 L
.82771 .27053 L
.81906 .28052 L
.80588 .2956 L
.80128 .30076 L
.78404 .31999 L
.78312 .321 L
.76468 .34123 L
.7622 .34394 L
.74594 .36147 L
.74036 .36744 L
.72688 .38171 L
.71852 .39049 L
.70752 .40194 L
.69668 .41315 L
.68786 .42218 L
.67484 .43543 L
.66792 .44242 L
.653 .45737 L
.64769 .46265 L
.63116 .47899 L
.62719 .48289 L
.60932 .50031 L
.60641 .50313 L
.58749 .52134 L
.58536 .52336 L
.56565 .54209 L
.56405 .5436 L
.54381 .56258 L
.54246 .56384 L
.52197 .58281 L
Mistroke
.5206 .58407 L
.50013 .60279 L
.49846 .60431 L
.47829 .62252 L
.47603 .62455 L
.45645 .64199 L
.4533 .64478 L
.43461 .66122 L
.43027 .66502 L
.41277 .68019 L
.4069 .68526 L
.39093 .6989 L
.38318 .70549 L
.36909 .71735 L
.35908 .72573 L
.34726 .73552 L
.33456 .74597 L
.32542 .7534 L
.30957 .7662 L
.30358 .77098 L
.28404 .78644 L
.28174 .78824 L
.2599 .80521 L
.25804 .80668 L
.23806 .82188 L
.23146 .82691 L
.21622 .83812 L
.20389 .84715 L
.19438 .85386 L
.17502 .86739 L
.17254 .86905 L
.1507 .88389 L
.14557 .88762 L
.12886 .89794 L
.11261 .90786 L
.10703 .91082 L
.08519 .92318 L
.07349 .9281 L
.06335 .9328 L
.04151 .93836 L
.02381 .9281 L
.0262 .90786 L
.03744 .88762 L
.04151 .87853 L
.04948 .86739 L
.06335 .84727 L
.0635 .84715 L
.07812 .82691 L
.08519 .81736 L
.09361 .80668 L
Mistroke
.10703 .78975 L
.10981 .78644 L
.12649 .7662 L
.12886 .76334 L
.14355 .74597 L
.1507 .73758 L
.16101 .72573 L
.17254 .71256 L
.17883 .70549 L
.19438 .68811 L
.19697 .68526 L
.21539 .66502 L
.21622 .66411 L
.23402 .64478 L
.23806 .64043 L
.2529 .62455 L
.2599 .61711 L
.27202 .60431 L
.28174 .5941 L
.29135 .58407 L
.30358 .57138 L
.31089 .56384 L
.32542 .54892 L
.33063 .5436 L
.34726 .52671 L
.35057 .52336 L
.36909 .50473 L
.3707 .50313 L
.39093 .48297 L
.39102 .48289 L
.41151 .46265 L
.41277 .46142 L
.43219 .44242 L
.43461 .44006 L
.45307 .42218 L
.45645 .41892 L
.47414 .40194 L
.47829 .39798 L
.49541 .38171 L
.50013 .37725 L
.51689 .36147 L
.52197 .35672 L
.53859 .34123 L
.54381 .3364 L
.56052 .321 L
.56565 .3163 L
.58269 .30076 L
.58749 .29642 L
.60513 .28052 L
.60932 .27677 L
Mistroke
.62785 .26029 L
.63116 .25737 L
.65089 .24005 L
.653 .23821 L
.67428 .21981 L
.67484 .21933 L
.69668 .20073 L
.69803 .19958 L
.71852 .18243 L
.72221 .17934 L
.74036 .16448 L
.74692 .1591 L
.7622 .14691 L
.77229 .13887 L
.78404 .12977 L
.79849 .11863 L
.80588 .11313 L
.82584 .09839 L
.82771 .09706 L
.84955 .0816 L
.85417 .07816 L
.87139 .06696 L
.88523 .05792 L
.89323 .05347 L
.91507 .04127 L
.92283 .03768 L
.93691 .03142 L
Mfstroke
0 0 1 r
.5005 .49695 m
matrix currentmatrix
0.0112195 0.00855199 scale
44.6098 58.1093 1 0 365.73 arc
setmatrix F
0 g
gsave
.33935 .4653 -96.5938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
88.313 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
115.188 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
130.188 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50764 .80738 -107.875 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 43.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
88.313 31.938 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
115.188 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
152.750 31.938 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{430, 430},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006^0001[R000`400?l00000o`00003oo`3ooon_
0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_
0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3ooon_0?ooo`00o`3oool1
0?ooo`050?noM000000000000000M02oool0Z@3oool00?l0oooo00L0gia80000B02Lgol0oooo0?no
M0000000M;oo0:P0oooo003n0?ooo`030?oOW0180000B9cO00<0oooo00<0gia80000M02oool0Y`3o
ool00?h0oooo00<0gia80000M02oool00`3oool00`3ogi`0B00007Boo`2W0?ooo`00k03oool00`3o
oml0W4Q809cOo`050?ooo`030?oOW018B9`0gooo00H0oooo00@0oooO09a80000B9`0gooo0`3oool0
0`3ookl0M000001d_`2W0?ooo`00k03oool00`3ogi`0B000001d_`050?ooo`030=nLB00004P0W=oo
00H0oooo00<0oono07@00000M;l0103oool0103ookl0M0000018W03OoonV0?ooo`00k03oool0103O
W4P000000000M02oool30?ooo`040?oo_`1d0000000004RLg`H0oooo00<0omnL04P00000M;l0103o
ool0103ooml0W4P00000M02ooonV0?ooo`00j`3oool01@3ooml0W4P0000000000000B9cO00<0oooo
00D0okmd000000000000001d0;ooo`050?ooo`030?oOW018000007Bo00@0oooo00@0oooO09a80000
07@0_oooYP3oool00>/0oooo00H0okmd0000000004P0W;nL04P0M02oool20?ooo`050;md00000000
04Qd07A8001d_ol01@3oool0103ookl0M0000018W03Oool30?ooo`040?oog`2LB00004RL0=ooojH0
oooo003[0?ooo`0=0;md0000000007Bo0?ooo`2oM000M;oo0?ooo`3ookl0M0000000001d_ol0okmd
001d_`050?ooo`040?oog`2LB00004RL0=ooo`<0oooo00<0oono07@00000M;l0Y`3oool00>X0oooo
00l0oono07@000000000M;oo0?ooo`3o_g@004RL0=ooo`3OW4P000000000M02oool0oono07@0B02L
gol01@3oool00`3OW4P0001809cOo`030?ooo`030?oOW0180000B9cO0:L0oooo003Z0?ooo`0;0?no
M0000000001d0;ooo`3oool0oooO09a8001d_ml0W4P000000018W=l00P3oool00`2oM000B9cO0?oo
o`040?ooo`030?oo_`1d0000B9cO00<0oooo00<0gia80000M02oool0Y`3oool00>T0oooo00@0oooO
09a80000000007Bo0`3oool01@3o_g@004Q804P0000004P0W=oo0080oooo00<0omnL04Q8W03Oool0
1@3oool01`3o_g@0001809cOo`3oool0omnL04P0001d_ol0Z03oool00>T0oooo00@0omnL04P00000
0000M;oo0`3oool01@3ookl0M00000000000B9`0gooo0080oooo00<0oooO09a8001d_ol01P3oool0
1@3ogi`0B0000000000004P0W=oo0:T0oooo003Y0?ooo`040=nLB000000004RL0=ooo`<0oooo00@0
oono07@000000000M;oo103oool00`3OW4P007Bo0?ooo`2c0?ooo`00j03oool0103ookl0M0000000
0018W=l40?ooo`040?noM0000000001d0;ooo`@0oooo00<0omnL04P0M02oool0/`3oool00>P0oooo
00@0_g@0000000000000B9cO0`3oool01@3ookl0M0000000000004P0W=oo00@0oooo00<0oono07@0
0000M;l0/`3oool00>H0oooo00<0oooO09a8000000000`0000000`00M;l0oooo0=nLB00500000004
001d_`3oool0oooo0?noM0<0000000<004RL0=ooo`3oool0/03oool00?l0oooo[`3oool00?l0oooo
[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo
[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo
[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo
[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo[`3oool00?l0oooo
[`3oool00640oooo00<0oono07@0000000001@0000000`18W=l0oooo0?ooo`030?ooo`040?oOW018
0000001809cOo`L0oooo00<0gia80000B02Lgol02@3oool00`3OW4P00000000000020000000304RL
g`3oool0oooo00T0oooo00<0oono07@0000000001@0000000`18W=l0oooo0?ooo`030?ooo`040?oO
W0180000001809cOo`@0oooo00<0gia80000000000000P0000000`18W=l0oooo0?ooo`090?ooo`03
0?oo_`1d0000000000D0000000<0B9cO0?ooo`3oool00`3oool0103ogi`0B0000000B02Lgol20?oo
o`030?noM0000000000000T0000000<0B9cO0?ooo`3oool00P3oool00`3OW4P00000000000020000
000304RLg`3oool0oooo01D0oooo00<0oono07@0000000001@0000000`18W=l0oooo0?ooo`0C0?oo
o`050;md0000000000000000001d_ol01`3oool0103ogi`0B0000000B02Lgol70?ooo`030=nLB000
04P0W=oo00T0oooo00<0gia80000000000000P0000000`18W=l0oooo0?ooo`0;0?ooo`050;md0000
000000000000001d_ol01`3oool0103ogi`0B0000000B02Lgol40?ooo`030=nLB000000000000080
000000<0B9cO0?ooo`3oool02`3oool01@2oM0000000000000000000M;oo00L0oooo00@0omnL04P0
000004P0W=oo0P3oool00`3o_g@00000000000090000000304RLg`3oool0oooo0080oooo00<0gia8
0000000000000P0000000`18W=l0oooo0?ooo`080?ooo`00H`3oool01@3ookl0M000000000000000
M;oo00L0oooo00@0_g@000000000000007Bo1`3oool00`3ookl0M000001d_`080?ooo`030?noM000
0000000000D0000000<0M;oo0?ooo`3oool02@3oool01@3ookl0M000000000000000M;oo00L0oooo
00@0_g@000000000000007Bo0`3oool00`3o_g@00000000000050000000307Boo`3oool0oooo00T0
oooo00D0oono07@000000000000007Boo`070?ooo`040;md000000000000001d_`<0oooo00<0okmd
000000000000200000001@00B9`0gooo0?ooo`3oool0okmd00L0000000<0M;oo0?ooo`3oool05@3o
ool01@3ookl0M000000000000000M;oo01D0oooo00T0oono07@0000007@0_ooo0?ooo`3o_g@00000
0018W03Oool01@3oool0102oM000000000000000M;l70?ooo`030?oo_`1d000007Bo00P0oooo00<0
okmd0000000000001@0000000`1d_ol0oooo0?ooo`070?ooo`090?oo_`1d0000001d0;ooo`3oool0
okmd00000000B9`0gooo00D0oooo00@0_g@000000000000007Bo0`3oool00`3o_g@0000000000005
0000000307Boo`3oool0oooo00L0oooo00T0oono07@0000007@0_ooo0?ooo`3o_g@000000018W03O
ool01@3oool0102oM000000000000000M;l30?ooo`030?noM0000000000000P0000000D004RL0=oo
o`3oool0oooo0?noM0070000000307Boo`3oool0oooo00H0oooo001T0?ooo`040;md00000000001d
0;ooo`L0oooo00@0omnL04P0000004P0W=oo203oool00`2oM000001d0;ooo`070?ooo`030?oog`2L
B000B9cO00@0oooo00<0gia800000018W=l02`3oool0102oM00000000000M02oool70?ooo`040?oO
W0180000001809cOo`<0oooo00<0oooO09a80018W=l0103oool00`3OW4P0000004RLg`0;0?ooo`04
0;md00000000001d0;ooo`L0oooo00@0omnL04P0000004P0W=oo103oool00`3ogi`0B01d0;ooo`06
0?ooo`030?oo_`1d0000M;oo0080oooo00<0oooO09a80018W=l0103oool00`3OW4P0000004RLg`0G
0?ooo`040;md00000000001d0;oooa@0oooo00@0oooO09a800000000M;oo0`3oool00`3o_g@00000
001d_`050?ooo`040?oOW0180000001809cOo`P0oooo00<0_g@00000M02oool01`3oool00`3ooml0
W4P004RLg`040?ooo`030=nLB0000000B9cO00L0oooo00@0oooO09a800000000M;oo0`3oool00`3o
_g@00000001d_`050?ooo`040?oOW0180000001809cOo`<0oooo00<0oooO09a80018W=l0103oool0
0`3OW4P0000004RLg`070?ooo`040?oog`2LB000000007Boo`<0oooo00<0okmd00000000M;l01@3o
ool0103ogi`0B0000000B02Lgol40?ooo`030?oOW01807@0_ooo00H0oooo00<0oono07@0001d_ol0
0P3oool00`3ooml0W4P004RLg`040?ooo`030=nLB0000000B9cO00L0oooo001T0?ooo`040=nLB000
0000001d0;oooa<0oooo00<0okmd0000001d_ol03`3oool00`3o_g@0000007Boo`0:0?ooo`040=nL
B0000000001d0;oooaH0oooo00<0okmd0000001d_ol02P3oool0103OW4P000000000M02oool@0?oo
o`030?oOW01807@0_ooo00H0oooo00<0oono07Ad_`3oool02@3oool00`3o_g@0000007Boo`0F0?oo
o`040=nLB0000000001d0;oooa@0oooo00@0okmd00000000B9`0gooo0`3oool0103ookl0M0000000
001d_ol@0?ooo`030?noM0000000M;oo00l0oooo00<0okmd0000001d_ol01P3oool0103o_g@00000
0018W03Oool30?ooo`040?oo_`1d0000000007Booa<0oooo00<0okmd0000001d_ol01P3oool0103o
_g@000000018W03Oool30?ooo`040?oo_`1d0000000007Boo`d0oooo00<0omnL04P0M02oool01P3o
ool00`3ookl0M7Bo0?ooo`090?ooo`030?noM0000000M;oo00H0oooo001T0?ooo`040=nLB0000000
001d0;oooa<0oooo00<0oono07@00000M;l0403oool00`2oM00004RL0=ooo`090?ooo`040=nLB000
0000001d0;oooaL0oooo00<0_g@00018W03Oool02@3oool0103OW4P000000000M02ooolA0?ooo`03
0?noM00007@0_ooo0180oooo00<0_g@00018W03Oool05@3oool0103OW4P000000000M02ooolC0?oo
o`040?oog`2LB000000004RLg`D0oooo00<0_g@000000000M;l0403oool00`3ookl0M000001d_`0@
0?ooo`030;md0000B9`0gooo00@0oooo00@0oooO09a800000000B9cO1@3oool00`2oM0000000001d
_`0D0?ooo`030;md0000B9`0gooo00@0oooo00@0oooO09a800000000B9cO1@3oool00`2oM0000000
001d_`0>0?ooo`030?noM00007@0_ooo0180oooo00<0_g@00018W03Oool01@3oool006@0oooo00@0
gia80000000007@0_ooo503oool00`2oM000001d0;ooo`0?0?ooo`030?noM00004P0W=oo00T0oooo
00@0gia80000000007@0_ooo5`3oool00`3o_g@0001809cOo`090?ooo`040=nLB0000000001d0;oo
oa80oooo00<0okmd0018W03Oool04@3oool00`3o_g@0001809cOo`0E0?ooo`040=nLB0000000001d
0;oooa<0oooo00@0omnL04P000000000M;oo1@3oool0103OW4P000000000B02Lgol@0?ooo`030;md
000007@0_ooo00l0oooo00<0okmd0000B02Lgol0103oool0103ogi`0B0000000001d_ol50?ooo`04
0=nLB0000000001809cOoa<0oooo00<0okmd0000B02Lgol0103oool0103ogi`0B0000000001d_ol5
0?ooo`040=nLB0000000001809cOo`h0oooo00<0okmd0018W03Oool04@3oool00`3o_g@0001809cO
o`050?ooo`00I03oool0103OW4P000000000M02ooolD0?ooo`030?noM0000000M;oo00l0oooo00<0
okmd00000018W=l02@3oool0103OW4P000000000M02ooolG0?ooo`030?noM0000000B9cO00T0oooo
00@0gia80000000007@0_ooo4`3oool00`3OW4P004RL0=ooo`0@0?ooo`030?noM0000000B9cO01D0
oooo00@0gia80000000007@0_ooo4`3oool0103OW4P000000000B02Lgol50?ooo`040?noM0000000
000007Booa00oooo00<0okmd0000001d_ol03`3oool00`3o_g@0000004RLg`040?ooo`040=nLB000
0000001809cOo`D0oooo00@0okmd000000000000M;oo4`3oool00`3o_g@0000004RLg`040?ooo`04
0=nLB0000000001809cOo`D0oooo00@0okmd000000000000M;oo3`3oool00`3OW4P004RL0=ooo`0@
0?ooo`030?noM0000000B9cO00D0oooo001:0?ooo`030?oo_`1d0000000000d0000000<0M;oo0?oo
o`3oool01`3oool0103OW4P000000000M02ooolD0?ooo`030?oo_`1d000007Bo0080oooo00<0oono
07@0000000003@0000000`1d_ol0oooo0?ooo`060?ooo`040=nLB0000000001d0;ooo`X0oooo00<0
oono07@0000000003@0000000`1d_ol0oooo0?ooo`060?ooo`040=nLB0000000001d0;oooa@0oooo
00<0_g@0001d_`3oool03@3oool00`3ookl0M0000000000=0000000307Boo`3oool0oooo00L0oooo
00@0gia80000000005L0E`003P0000000`1d_ol0oooo0?ooo`020?ooo`040;md00000000001809cO
o`D0oooo00@0okmd000000000000B9cO403oool01P3ookl0M000001d_`3oool0oono07@000h00000
00<087CO0?ooo`3oool00P3oool0102oM00000000000B02Lgol50?ooo`040?noM0000000000004RL
g`D0oooo00<0oono07@0000000003@0000000`0PM=l0oooo0?ooo`020?ooo`040;md000000000018
09cOo`D0oooo00@0okmd000000000000B9cO403oool00`2oM00007Bo0?ooo`0?0?ooo`030=nLB000
0000B9cO00D0oooo001:0?ooo`030?oo_`1d0000000000d0000000<0M;oo0?ooo`3oool01`3oool0
103OW4P000000000M02ooolE0?ooo`060;md000007@0_ooo0?ooo`3ookl0M0003P0000000`1d_ol0
oooo0?ooo`060?ooo`040=nLB0000000001d0;ooo`X0oooo00<0oono07@0000000003@0000000`1d
_ol0oooo0?ooo`060?ooo`040=nLB0000000001d0;oooa@0oooo00<0oono07@00018W=l03@3oool0
0`3ookl0M0000000000=0000000307Boo`3oool0oooo00L0oooo00@0gia80000000005L0E`003P00
00002@1d_ol0oooo0?ooo`3oool0oooO09a800000000001d0;ooo`050?ooo`040?oOW01800000000
001d_a40oooo00D0_g@00000M02oool0oono07@0000>00000009021dg`3oool0oooo0?ooo`3ooml0
W4P00000000007@0_ooo00D0oooo00@0omnL04P00000000007Bo1@3oool00`3ookl0M0000000000=
00000009021dg`3oool0oooo0?ooo`3ooml0W4P00000000007@0_ooo00D0oooo00@0omnL04P00000
000007Bo403oool00`3ookl0M00004RLg`0>0?ooo`040?oo_`1d0000000004RLg`D0oooo001T0?oo
o`040=nLB0000000001d0;oooaD0oooo00<0okmd00000018W=l0303oool01@3ooml0W4P000000000
04P0W=oo00T0oooo00@0gia80000000007@0_ooo5@3oool01@3ooml0W4P00000000004P0W=oo00T0
oooo00@0gia80000000007@0_ooo5@3oool00`3o_g@0000007Boo`0<0?ooo`050?oog`2LB0000000
0000B02Lgol05@3oool0103OW4P000000000M02ooolB0?ooo`050?oog`2LB00000000000M02oool0
1@3oool0103ogi`0B00000000000M;lA0?ooo`030?noM0000000B9cO00`0oooo00D0oooO09a80000
0000001809cOo`030?ooo`050?oog`2LB00000000000M02oool01@3oool0103ogi`0B00000000000
M;lA0?ooo`050?oog`2LB00000000000B02Lgol00`3oool01@3ooml0W4P00000000007@0_ooo00D0
oooo00@0omnL04P00000000007Bo4@3oool00`3o_g@0000007Boo`0<0?ooo`050?oog`2LB0000000
0000B02Lgol01@3oool006@0oooo00@0gia80000000007@0_ooo5@3oool0103ooml0W4P00018W03O
ool:0?ooo`060?oo_`1d0000000000000000B9`0gooo2@3oool0103OW4P000000000M02ooolD0?oo
o`060?oo_`1d0000000000000000B9`0gooo2@3oool0103OW4P000000000M02ooolE0?ooo`040?oo
g`2LB000001d0;ooo`X0oooo00H0oono07@00000000000000018W03OoolE0?ooo`040=nLB0000000
001d0;oooa80oooo00D0oooO09a800000000001d0;ooo`050?ooo`040?oOW01800000000001d_a40
oooo00@0oooO09a80000B9`0gooo2P3oool01P3ookl0M00000000000000004RL0=ooo`<0oooo00D0
oooO09a800000000001d0;ooo`050?ooo`040?oOW01800000000001d_a00oooo00H0oono07@00000
000000000018W03Oool30?ooo`050?oog`2LB00000000000M02oool01@3oool0103ogi`0B0000000
0000M;lA0?ooo`040?oog`2LB000001d0;ooo`X0oooo00H0oono07@00000000000000018W03Oool5
0?ooo`00I03oool0103OW4P000000000M02ooolF0?ooo`030=nLB00004P0W=oo00P0oooo00<0omnL
04P0000000000P0000000`0004P0W=oo0?ooo`090?ooo`040=nLB0000000001d0;oooa80oooo00<0
omnL04P0000000000P0000000`0004P0W=oo0?ooo`090?ooo`040=nLB0000000001d0;oooaH0oooo
00<0gia800000018W=l0203oool00`3ogi`0B00000000002000000030000B02Lgol0oooo01D0oooo
00@0gia80000000007@0_ooo4`3oool0102oM00000000000B02Lgol50?ooo`040?oOW01800000000
001d_a80oooo00<0gia80000B02Lgol0203oool00`3ogi`0B00000000002000000030000B02Lgol0
oooo00@0oooo00@0_g@00000000004P0W=oo1@3oool0103ogi`0B00000000000M;l>0?ooo`030?oO
W018000000000080000000<0001809cOo`3oool0103oool0102oM00000000000B02Lgol50?ooo`04
0?oOW01800000000001d_a80oooo00<0gia800000018W=l0203oool00`3ogi`0B000000000020000
00030000B02Lgol0oooo00D0oooo001T0?ooo`040=nLB0000000001d0;oooaH0oooo00<0omnL04P0
0018W=l01@3oool00`2oM0000000000000050000000307Boo`3oool0oooo00T0oooo00@0gia80000
000007@0_ooo3`3oool00`2oM0000000000000050000000307Boo`3oool0oooo00T0oooo00@0gia8
0000000007@0_ooo5P3oool0103ogi`0B0000000M02oool40?ooo`030;md00000000000000D00000
00<0M;oo0?ooo`3oool05@3oool0103OW4P000000000M02ooolC0?ooo`040;md00000000001809cO
o`D0oooo00@0omnL04P000000000B9cO4P3oool00`3ogi`0B00004RLg`050?ooo`030;md00000000
000000D0000000<0M;oo0?ooo`3oool0103oool0102oM00000000000B02Lgol50?ooo`040?oOW018
0000000004RLg`/0oooo00<0_g@00000000000001@0000000`1d_ol0oooo0?ooo`040?ooo`040;md
00000000001809cOo`D0oooo00@0omnL04P000000000B9cO4P3oool0103ogi`0B0000000M02oool4
0?ooo`030;md00000000000000D0000000<0M;oo0?ooo`3oool01@3oool006@0oooo00@0gia80000
000007@0_ooo5P3oool0103ooml0W4P00018W03Oool40?ooo`030?oOW0180000000000<0000000<0
001d0;ooo`3oool02`3oool0103OW4P000000000M02oool?0?ooo`030?oOW0180000000000<00000
00<0001d0;ooo`3oool02`3oool0103OW4P000000000M02ooolF0?ooo`040?oo_`1d0000000007Bo
o`@0oooo00<0omnL04P0000000000`0000000`0007@0_ooo0?ooo`0G0?ooo`040=nLB0000000001d
0;oooa<0oooo00@0gia8000000000000M;oo1@3oool0103o_g@000000000001d_olB0?ooo`040?oo
g`2LB00004RL0=ooo`@0oooo00<0omnL04P0000000000`0000000`0007@0_ooo0?ooo`060?ooo`04
0=nLB0000000000007Boo`D0oooo00@0okmd000000000000M;oo2`3oool00`3ogi`0B00000000003
000000030000M02oool0oooo00H0oooo00@0gia8000000000000M;oo1@3oool0103o_g@000000000
001d_olB0?ooo`040?oo_`1d0000000007Boo`@0oooo00<0omnL04P0000000000`0000000`0007@0
_ooo0?ooo`070?ooo`00I03oool0103OW4P000000000M02oool>0?ooo`030=oOg`3oool0oooo00H0
oooo00<0gia80000B02Lgol01@3oool01@2oM000000000000000B9`0gooo00h0oooo00@0gia80000
000007@0_ooo403oool01@2oM000000000000000B9`0gooo00h0oooo00@0gia80000000007@0_ooo
5P3oool0103ogi`0B00000000018W=l50?ooo`050;md0000000000000018W03Oool06P3oool0103O
W4P000000000M02ooolC0?ooo`040?oOW0180000000004RLg`D0oooo00@0gia80000000004P0W=oo
2P3oool00`3Ogml0oooo0?ooo`060?ooo`030=nLB00004P0W=oo00D0oooo00D0_g@0000000000000
04RL0=ooo`090?ooo`040?oOW0180000000004RLg`D0oooo00@0gia80000000004P0W=oo303oool0
1@2oM000000000000000B9`0gooo00T0oooo00@0omnL04P000000000B9cO1@3oool0103OW4P00000
0000B02LgolB0?ooo`040?oOW0180000000004RLg`D0oooo00D0_g@000000000000004RL0=ooo`0:
0?ooo`00I03oool0102oM00000000000M02oool>0?ooo`030=nLB01d_ol0oooo00H0oooo00<0omnL
04P00018W=l01@3oool00`3o_g@004RL0=ooo`0@0?ooo`040;md00000000001d0;oooa00oooo00<0
okmd0018W03Oool0403oool0102oM00000000000M02oool=0?ooo`030?oog`2LM9`0gooo00H0oooo
00@0okmd000000000000B9cO1@3oool00`3o_g@004RL0=ooo`0L0?ooo`040;md00000000001d0;oo
oa<0oooo00@0oooO09a80000000007Bo1@3oool0102oM00000000018W03Oool:0?ooo`030=nLB01d
_ol0oooo00H0oooo00<0omnL04P00018W=l01@3oool00`3o_g@004RL0=ooo`0;0?ooo`040?oog`2L
B0000000001d_`D0oooo00@0_g@000000000B9`0gooo303oool00`3o_g@004RL0=ooo`0;0?ooo`04
0?oog`2LB0000000001d_`D0oooo00@0_g@000000000B9`0gooo2@3oool00`3ooml0W7BL0=ooo`06
0?ooo`040?noM0000000000004RLg`D0oooo00<0okmd0018W03Oool0303oool006@0oooo00@0_g@0
0000000007@0_ooo3P3oool00`3ogi`0B00007Boo`060?ooo`040?oog`2LB00004RL0=ooo`@0oooo
00<0oooO09a8B02Lgol0403oool0102oM00000000000M02oool@0?ooo`030?oog`2LB4P0W=oo0100
oooo00@0_g@00000000007@0_ooo3P3oool00`3OW4P0B9cO0?ooo`040?ooo`050?oo_`1d00000000
0000B02Lgol01@3oool00`3ooml0W4Q809cOo`0L0?ooo`040;md00000000001d0;oooa@0oooo00@0
okmd00000000B9`0gooo0`3oool0103ookl0M0000000001d_ol;0?ooo`030?oOW0180000M;oo00H0
oooo00@0oooO09a80000B9`0gooo103oool00`3ooml0W4Q809cOo`0<0?ooo`040?noM000000004RL
0=ooo`<0oooo00@0oono07@000000000M;oo3@3oool00`3ooml0W4Q809cOo`0<0?ooo`040?noM000
000004RL0=ooo`<0oooo00@0oono07@000000000M;oo2`3oool00`3OW4P0B9cO0?ooo`040?ooo`05
0?oo_`1d000000000000B02Lgol01@3oool00`3ooml0W4Q809cOo`0<0?ooo`00H@3oool00`3o_g@0
000000000002000000030000M02oool0oooo00d0oooo00<0oooO09a8000000002@0000000`1d_ol0
oooo0?ooo`030?ooo`030?noM0000000000000@0000000<004RL0=ooo`3oool01@3oool00`3o_g@0
000000000002000000030000M02oool0oooo0100oooo00<0okmd000000000000100000000`00B9`0
gooo0?ooo`050?ooo`030?noM000000000000080000000<0001d0;ooo`3oool03@3oool0103ookl0
M0000018W03Oool20?ooo`050?oOW0180000000000000000M;l01`3oool00`3o_g@0000000000004
000000030018W03Oool0oooo0140oooo00<0okmd0000000000000P0000000`0007@0_ooo0?ooo`0D
0?ooo`030;md00000000M;oo00<0oooo00<0okmd00000000M;l0303oool00`3ooml0W4P000000009
0000000307Boo`3oool0oooo00<0oooo00<0okmd000000000000100000000`00B9`0gooo0?ooo`05
0?ooo`030;md00000000M;oo00<0oooo00<0okmd00000000M;l03`3oool00`3o_g@0000000000004
000000030018W03Oool0oooo00D0oooo00<0_g@00000001d_ol00`3oool00`3o_g@00000001d_`0<
0?ooo`040?oo_`1d000004RL0=ooo`80oooo00D0omnL04P0000000000000001d_`070?ooo`030?no
M0000000000000@0000000<004RL0=ooo`3oool0103oool00680oooo00H0okmd0000000000000000
0000M02oool?0?ooo`030=nLB0000000000000P0000000<007Bo0?ooo`3oool00`3oool00`3ooml0
W4P000000004000000030000B02Lgol0oooo00H0oooo00H0okmd00000000000000000000M02ooolA
0?ooo`030?oog`2LB000000000@0000000<0001809cOo`3oool01P3oool01P3o_g@0000000000000
0000001d0;ooo`l0oooo00<0okmd0000000000001@0000000`00B9`0gooo0?ooo`060?ooo`030?oo
g`2LB000000000@0000000<0001809cOo`3oool04P3oool01P3o_g@00000000000000000001d0;oo
oaD0oooo00T0oooO09a8000004P0W=oo0?ooo`3ogi`0B0000018W03Oool03@3oool00`3OW4P00000
0000000800000003001d_`3oool0oooo00<0oooo00<0oooO09a800000000100000000`0004P0W=oo
0?ooo`050?ooo`090?oog`2LB000001809cOo`3oool0omnL04P00000B9`0gooo00l0oooo00<0oooO
09a800000000100000000`0004P0W=oo0?ooo`050?ooo`090?oog`2LB000001809cOo`3oool0omnL
04P00000B9`0gooo00d0oooo00<0okmd0000000000001@0000000`00B9`0gooo0?ooo`060?ooo`03
0?oog`2LB000000000@0000000<0001809cOo`3oool0103oool006@0oooo00@0oooO09a8000007@0
_ooo3`3oool00`3ogi`0B00000000008000000030018W03Oool0oooo00@0oooo00<0gia800000000
0000100000000`00M;l0oooo0?ooo`070?ooo`040?oog`2LB000001d0;oooa80oooo00<0gia80000
00000000100000000`00M;l0oooo0?ooo`070?ooo`040?oog`2LB000001d0;oooa00oooo00<0oooO
09a8000000000`0000000`1d_ol0oooo0?ooo`080?ooo`030=nLB0000000000000@0000000<007Bo
0?ooo`3oool04`3oool0103ooml0W4P00000M02ooolG0?ooo`050=nLB0000000000000000018W=l0
3`3oool00`3ogi`0B00000000008000000030018W03Oool0oooo00@0oooo00<0gia8000000000000
100000000`00M;l0oooo0?ooo`060?ooo`050=nLB0000000000000000018W=l04P3oool00`3OW4P0
00000000000400000003001d_`3oool0oooo00H0oooo00D0gia8000000000000000004RLg`0@0?oo
o`030?oog`2LB000000000<0000000<0M;oo0?ooo`3oool0203oool00`3OW4P00000000000040000
0003001d_`3oool0oooo00<0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o
0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o
0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo001A0?ooool00000C`00000?0?ooo`00D@3o
ool2000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo001A0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?oo
o`3oool03@3oool00540oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo00d0
oooo001A0?ooo`030000003oool0oooo0?l0ooooB`3oool00`000000oooo0?ooo`0=0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?ooo`3oool03@3oool00540oooo00<00000
0?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo
0?l0oooo?03oool2000000d0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3o
ool0o`3ooolj0?ooo`8000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0
oooo001A0?ooo`030000003oool0oooo0?l0oooo>03oool2000000D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooocD0oooo0`00
00080?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3o
0?oooc<0oooo0P00000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool0
0540oooo0P00003o0?oooc40oooo0`00000@0?ooo`030000003oool0oooo00<0oooo0`00000?0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?ooobh0oooo0P00000C0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0o`3oool/0?ooo`800000
5@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003o
ool0oooo0?l0oooo:P3oool2000001L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0=0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooobP0oooo0P00000I0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0o`3ooolV0?oo
o`8000006`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo001A0?ooo`03
0000003oool0oooo0?l0oooo903oool2000001d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003o
ool0oooo0?l0oooo8@3oool2000001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0=0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooob00oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo
0?l0oooo7P3oool200000240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0?l0oooo
6`3oool2000002<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00d0oooo001A0?ooo`800000o`3ooolJ0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool01`3oool3000000l0oooo001A0?ooo`030000003oool0oooo
0?l0oooo5`3oool2000002H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?oooaH0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0?l0oooo
503oool2000002P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oooa80oooo0P00000Y0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03@3oool004@0oooo00@0gia80000000007@0_ooo2@3oool00`000000oooo0?oo
o`3o0?oooa40oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00d0oooo00140?ooo`040=nLB0000000001d0;ooo`T0oooo00<000000?ooo`3oool0o`3o
oolA0?ooo`030000003oool0oooo01l0oooo0P0000070?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool004@0oooo00@0gia80000000007@0_ooo2@3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo0P00000P0?ooo`8000000P3oool2000000@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`00A03oool0103OW4P000000000M02oool90?ooo`030000003o
ool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`0N0?ooo`800000203oool00`000000oooo0000
000?0?ooo`030000003oool0oooo00d0oooo00140?ooo`040=nLB0000000001d0;ooo`T0oooo00<0
00000?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo01d0oooo0P00000;0?ooo`8000003`3o
ool00`000000oooo0?ooo`0=0?ooo`00?03oool00`3o_g@000000000000:00000003001d_`3oool0
oooo00D0oooo00<000000?ooo`3oool0o`3oool;0?ooo`8000007@3oool00`000000oooo0?ooo`0=
0?ooo`040000003oool00000000000d0oooo00<000000?ooo`3oool03@3oool003`0oooo00<0okmd
0000000000002P0000000`00M;l0oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo2P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo00d0oooo000X0?ooo`030?oo_`1d0000000000d0000000L0M;oo
0?ooo`3oool0oooo0?oog`2LB000M;oo00D0oooo00@0gia80000000007@0_ooo2@3oool00`000000
oooo0?ooo`3o0?ooo`T0oooo00<000000?ooo`3oool06`3oool200000100oooo00@000000?ooo`3o
ool000003P3oool00`000000oooo0?ooo`0=0?ooo`00:03oool00`3ookl0M0000000000=00000003
07Boo`3oool0oooo0080oooo00<0okmd0018W03Oool0103oool0103OW4P000000000M02oool90?oo
o`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`0J0?ooo`8000004@3oool01@00
0000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool03@3oool003h0oooo00<0_g@004RL
g`3oool00`3oool0103OW4P000000000M02oool90?ooo`<00000o`3oool60?ooo`8000006`3oool2
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`<000003`3oool0
03h0oooo00<0oono07@0B02Lgol00`3oool0103OW4P000000000M02oool90?ooo`030000003oool0
oooo0?l0oooo103oool2000001`0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<000000?ooo`3oool03@3oool003l0oooo00<0okmd0018W03Oool00P3oool0
103OW4P000000000M02oool90?ooo`030000003oool0oooo0?l0oooo0`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`00@03oool0202oM000B9cO0?ooo`3oool0gia80000000007@0_ooo2@3oool00`000000
oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00400oooo00P0oono07@0B02Lgol0
oooo0=nLB0000000001d0;ooo`T0oooo00<000000?ooo`3oool0o`3oool2000001/0oooo0P00000F
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00440oooo00L0okmd0018
W03Oool0gia80000000007@0_ooo00T0oooo00<000000?ooo`3oool0oP3oool00`000000oooo0?oo
o`0I0?ooo`8000005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00480oooo00H0_g@007Boo`3OW4P000000000M02oool90?ooo`030000
003oool0oooo0?d0oooo00<000000?ooo`3oool0603oool2000001P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00120?ooo`060?oo_`1d
07@0W9a80000000007@0_ooo2@3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo01L0
oooo0P00000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`00@`3oool01@3o_g@000000000000007@0_ooo00T0oooo00<000000?ooo`3o
ool0n`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00140?ooo`040;md
00000000001d0;ooo`T0oooo00<000000?ooo`3oool0n@3oool2000003D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00140?ooo`040?oo
_`1d0000001d0;ooo`T0oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0?H0oooo0P00000I0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0?D0oooo00<000000?ooo`3oool05`3o
ool2000001d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00d0oooo001A0?ooo`030000003oool0oooo0?@0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0=0?ooo`00D@3oool200000?@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo0P00000A0?ooo`<000003`3oool00540
oooo00<000000?ooo`3oool0lP3oool00`000000oooo0?ooo`0F0?ooo`8000007`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0?40oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0k`3oool2000003T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo001A
0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=
0?ooo`00D@3oool00`000000oooo0?ooo`3]0?ooo`030000003oool0oooo01H0oooo0P00000Q0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?oo
o`00D@3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo01D0oooo0P00000R0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`00
D@3oool00`000000oooo0?ooo`3[0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
3@3oool00540oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00d0oooo001A0?ooo`030000003oool0oooo0>P0oooo0P00000G0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00d0oooo001A0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0
oooo001A0?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3T0?ooo`030000003oool0oooo01@0oooo0P00
000V0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03@3oool00540oooo00<00000
0?ooo`3oool0h`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00d0oooo001A0?oo
o`800000hP3oool2000001D0oooo0P00000W0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool06@3oool3000000l0oooo001A0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000
003oool0oooo0=l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`800000
00<0oooo0000003oool07@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0g@3oool2000001H0oooo00<0
00000?ooo`3oool00`3oool3000000@0oooo0P00000J0?ooo`8000002P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0=`0oooo00<00000
0?ooo`3oool06P3oool2000000T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?oo
o`3oool0f`3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo0?ooo`8000002`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3I0?ooo`8000005`3oool00`00
0000oooo0?ooo`02000000d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3o
ool0f03oool00`000000oooo0?ooo`0E0?ooo`80000000<0oooo0000000000003`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo01D0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0eP3oool00`000000oooo
0?ooo`0E0?ooo`040000003oool0000000000140oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0=H0oooo
00<000000?ooo`3oool04`3oool2000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
3@3oool00540oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool00000000001<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`0D0?ooo`8000005@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0=0?ooo`00D@3oool0
0`000000oooo0?ooo`3B0?ooo`800000503oool00`000000oooo0000000F0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00d0oooo001A0?ooo`800000dP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool00000
01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
02<0oooo0`00000?0?ooo`00D@3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo01<0
oooo0`00000G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool04`3oool2000001P0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03@3oool00540oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0B
0?ooo`8000006P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0=0?ooo`00?03oool00`3o_g@00000000000090000
000304RLg`3oool0oooo00H0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0B0?oo
o`8000006P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool03@3oool003d0oooo00<0okmd000000000000200000000`00B9`0gooo0?ooo`060?ooo`03
0000003oool0oooo0<X0oooo0P00000D0?ooo`8000006`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0=0?ooo`00
?P3oool00`3ogi`0B01d0;ooo`060?ooo`030?oo_`1d0000M;oo00L0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0B0?ooo`800000703oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0=0?ooo`00?`3o
ool00`3ogi`0B01d0;ooo`060?ooo`030?oo_`1dM;l0oooo00H0oooo00<000000?ooo`3oool0b03o
ool00`000000oooo0?ooo`0B0?ooo`8000007@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0=0?ooo`00@03oool0
0`3o_g@0001d0;ooo`0>0?ooo`030000003oool0oooo0<H0oooo0P00000C0?ooo`<000006P3oool4
000000030?ooo`000000000000h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00d0oooo00110?ooo`030?noM000B9`0gooo00d0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0B0?ooo`<000006P3oool010000000oooo0?ooo`000004
0?ooo`8000002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool03@3oool00480oooo00<0gia80018W03Oool0303oool00`000000oooo0?ooo`340?oo
o`030000003oool0oooo0180oooo0P00000J0?ooo`8000000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00d0oooo000X0?ooo`030?oo_`1d0000000000d0000000<0M;oo0?ooo`3o
ool0203oool00`2oM00007Bo0?ooo`0;0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool04P3oool2000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00d0oooo000X0?ooo`030?oo_`1d0000000000d0000000<0M;oo0?ooo`3oool0
203oool00`3ookl0M00004RLg`0;0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0
4@3oool2000001P0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
3@3oool004@0oooo00<0okmd0000001d_ol02P3oool300000<40oooo00<000000?ooo`3oool04@3o
ool2000001L0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02l0oooo0`00000?0?ooo`00A03oool0
103ooml0W4P00000M02oool90?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3o
ool004D0oooo00<0gia800000018W=l02@3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0
oooo0140oooo0P00000H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool0
04D0oooo00@0omnL04P0000007@0_ooo203oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo0100oooo0`00000G0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00d0oooo00150?ooo`040?oo_`1d0000000007Boo`P0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`0@0?ooo`<000005`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00d0oooo00150?ooo`040?oOW0180000000004RLg`P0oooo00<000000?ooo`3oool0^`3oool2
000001<0oooo00<000000?ooo`3oool04`3oool2000000/0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool03@3oool0
03`0oooo00<0oooO09adW03Oool01P3oool0103o_g@0000000000018W=l80?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0=0?ooo`00?@3oool00`3O
W4P0B9cO0?ooo`040?ooo`050?oo_`1d000000000000B02Lgol0203oool00`000000oooo0?ooo`2i
0?ooo`030000003oool0oooo0140oooo0P00000F0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0=0?ooo`00?@3oool0103ookl0M0000018W03Oool2
0?ooo`050?oOW0180000000000000000M;l02@3oool00`000000oooo0?ooo`2h0?ooo`030000003o
ool0oooo0100oooo0`00000F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0=0?ooo`00?P3oool00`3o_g@0000000000005000000030018W03Oool0
oooo00P0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0@0?ooo`8000005@3oool2
000000d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0=0?ooo`00?`3oool00`3o
oml0W4P0000000030000000307Boo`3oool0oooo00T0oooo00<000000?ooo`3oool0]`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0;H0
oooo00<000000?ooo`3oool03`3oool3000001@0oooo0P00000?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00d0
oooo001A0?ooo`030000003oool0oooo0;@0oooo0P00000A0?ooo`<000009@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0100oooo0P00
000D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`00D@3oool200000;<0oooo00<000000?ooo`3oool0403oool2000001@0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0k0?ooo`<000003`3oool00540oooo00<000000?oo
o`3oool0/@3oool00`000000oooo0?ooo`0?0?ooo`<000004`3oool200000140oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool03@3oool00540oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool000000180oooo0P00000B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0403oool200000180oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool0403oool200000180oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`090?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
3`3oool2000001<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0=0?ooo`00
D@3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`000000
9`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`000000D`3oool00`000000oooo0?ooo`0=0?ooo`00D@3o
ool00`000000oooo0?ooo`2Y0?ooo`8000004@3oool00`000000oooo0000000A0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool02@3oool2000000030?ooo`000000oooo05<0oooo00<0
00000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0@
0?ooo`<000004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00d0oooo001A
0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0403oool200000180oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000d0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo00l0oooo0`00000B0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0000000=0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool03@3oool00540oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0?0?ooo`80
00004`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool03@3oool00540oooo0P00002T0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`170?ooo`<000003`3o
ool00540oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
000002T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000=0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0X@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool000000140oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`000000G03oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo
0?ooo`2N0?ooo`8000004@3oool00`000000oooo0000000@0?ooo`8000005`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00l0oooo1000
000@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03@3oool00540oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`0?0?ooo`030000003oool000000140oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000`0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`000000403oool2000001P0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool03@3oool00540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=0?ooo`00
D@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo00h0oooo0`00000@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3o
ool2000000d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool0
0`000000oooo0?ooo`2G0?ooo`800000403oool00`000000oooo0000000@0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0000000<0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool000000100oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00h0
oooo0P0000000`3oool000000?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0303oool2000006D0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0
U03oool00`000000oooo0?ooo`0>0?ooo`040000003oool0000000000100oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0;0?ooo`800000303oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo00d0oooo001A0?ooo`800000U@3oool00`000000oooo0?ooo`0>0?ooo`800000
403oool2000001X0oooo00<000000?ooo`3oool02P3oool3000000`0oooo00<000000?ooo`3oool0
EP3oool3000000l0oooo001A0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool03P3o
ool200000100oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0000000d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0=0?ooo`00D@3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00d0oooo0`00000@0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool02`3oool2000000`0oooo0P00001K0?ooo`030000003oool0
oooo00d0oooo001A0?ooo`030000003oool0oooo0900oooo0P00000?0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`0=0?ooo`00@@3oool01@2oM0000000000000000000M;oo00/0oooo00<000000?ooo`3o
ool0CP3oool00`3ogi`0B0000000000200000004001d_`3oool0oooO09a80080000000<0001d0;oo
o`3oool0:P3oool01@2oM0000000000000000000M;oo00<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0000000@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02`3oool2
000000`0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0=0?ooo`00?`3oool02@3o
okl0M0000000M02oool0oooo0?noM000000004RL0=ooo`090?ooo`030000003oool0oooo04d0oooo
00@0okmd000000000000M;oo0P3oool02@3o_g@0001807AdB0000000001d0;ooo`3ookl0M4RL0=oo
o`0X0?ooo`0:0?oo_`1d0000001d0;ooo`3oool0okmd00000000B9`0gooo00000100oooo00<00000
0?ooo`000000403oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo0P00000<
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03@3oool003h0oooo00@0oooO09a8
00000000M;oo0`3oool00`3o_g@00000001d_`090?ooo`030000003oool0oooo04`0oooo00@0oooO
09a80000000007Bo103oool0203ookl0M00000000000B9`0gooo0?ooo`3ogi`0M9cO9`3oool0103o
oml0W4P00000001d_ol30?ooo`030?noM000000000000100oooo00<000000?ooo`000000403oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`0=0?ooo`00?P3oool0103o_g@000000018W03Oool30?ooo`040?oo_`1d0000
000007Boo`P0oooo00<000000?ooo`3oool0C03oool0103ogi`0B00000000018W=l50?ooo`040?no
M000000004RL0=ooo`h0oooo00<0oono07@0000000003@0000000`1d_ol0oooo0?ooo`090?ooo`04
0?noM000000004RL0=ooo`<0oooo00@0oono000000000000M;oo3P3oool00`000000oooo0000000?
0?ooo`8000006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool03@3oool003d0oooo00@0oooO09a800000000B9cO1@3oool00`2oM0000000001d_`08
0?ooo`030000003oool0oooo04`0oooo00@0omnL04P000000000M;oo1@3oool0103ookl0M0000000
001d_ol>0?ooo`030?oo_`1d0000000000d0000000<0M;oo0?ooo`3oool0203oool0103ooml0W4P0
00000018W=l40?ooo`040000002oM0000000001d_`d0oooo00<000000?ooo`0000003`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool03@3oool000`0oooo00<0oooO09adW03Oool0;P3oool0103ogi`0
B0000000001d_ol50?ooo`040=nLB0000000001809cOo`L0oooo00<000000?ooo`3oool0C03oool0
103ogi`0B00000000018W=l60?ooo`040;md00000000001d0;ooobP0oooo00@0omnL04P000000000
M;oo0`3oool01P000000oooo0=nLB0000000001809cOo`X0oooo0P0000000`3oool000000?ooo`0>
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02`3oool2000000d0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`0=0?ooo`00303oool00`3ooml0W4P0001d_`0^0?oo
o`040=nLB0000000001809cOo`D0oooo00@0okmd000000000000M;oo1`3oool00`000000oooo0?oo
o`1<0?ooo`040?oo_`1d00000000001d_`H0oooo00D0gia800000018B4P004RL0=ooo`0W0?ooo`04
0=nLB0000000001809cOo`80oooo00@000000?ooo`3oool0okmd0P0000000`1d_ol0oooo0?ooo`07
0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0;0?ooo`8000003@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00d0oooo000<
0?ooo`030?oog`2LB00000000080000000<0B9cO0?ooo`3oool0:@3oool0102oM00000000000B02L
gol50?ooo`040?noM0000000000004RLg`L0oooo00<000000?ooo`3oool0C@3oool0103OW4P00000
0018W03Oool50?ooo`050?noM000000004RL09ad0018W=l09`3oool01P2oM00000000000B02Lgol0
oooo000000<0oooo00@0okmd000000000000B9cO203oool010000000oooo0?ooo`00000/0?ooo`03
0000003oool0oooo00/0oooo0P00000=0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool03@3oool000`0oooo00<0oooO09a8000000001@0000000`0007@0_ooo0?ooo`0U0?ooo`050?oo
g`2LB00000000000M02oool01@3oool0103ogi`0B00000000000M;l70?ooo`030000003oool0oooo
04d0oooo00@0oono07@000000000M;oo1@3oool01P3ogi`0B0000000M02ogi`0B00007BoobD0oooo
00H0oooO09a800000000001d0;ooo`0000040?ooo`040?oOW01800000000001d_`L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00d0oooo000<0?oo
o`050?oog`2LB7@0_ooo0?oOW01800001`0000000`1d_ol0oooo0?ooo`0Q0?ooo`050?oog`2LB000
00000000M02oool01@3oool0103ogi`0B00000000000M;l70?ooo`<00000CP3oool00`3o_g@00000
001d_`050?ooo`070?noM0000000001d0;ooo`3OW4P0001d0;ooo`0:0?ooo`030?oo_`1d00000000
00d0000000<0M;oo0?ooo`3oool01`3oool01@3ooml0W4P00000000007@0000000D0oooo00@0omnL
04P00000000007Bo1P3oool00`000000oooo0000000@0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool02`3oool2000000d0oooo00<000000?ooo`3oool0H`3oool3000000l0oooo000<
0?ooo`030?oog`2LW;l0oooo00@0oooo00<0_g@0000000000000100000000`0007@0_ooo0?ooo`0O
0?ooo`050?oog`2LB00000000000M02oool01@3oool0103ogi`0B00000000000M;l70?ooo`030000
003oool0oooo04l0oooo00<0gia80000001d_ol0103oool01`3OW4P000000018W03Oool0oono07@0
0000M;l02P3oool00`3ookl0M0000000000=0000000307Boo`3oool0oooo00L0oooo00D0oooO09a8
0000000000000;ooo`050?ooo`040?oOW01800000000001d_`D0oooo00<000000?ooo`000000403o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool03@3oool001H0oooo00D0omnL04P000000000000004RL
g`0R0?ooo`040;md00000000001809cOo`D0oooo00@0omnL04P00000000007Bo1`3oool00`000000
oooo0?ooo`1@0?ooo`030?noM0000000B9cO0080oooo00@0omnL04P000000000M;oo0P3oool00`3O
W4P00000001d_`0T0?ooo`040;md00000000001809cOo`D0oooo00@0omnL04P00000000007Bo103o
ool00`000000oooo0000000?0?ooo`800000703oool00`000000oooo0?ooo`0;0?ooo`8000003@3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00d0oooo000<0?ooo`030?oog`2LM9`0
gooo00L0oooo00<0_g@00000001d_ol0903oool0102oM00000000000B02Lgol50?ooo`040?oOW018
0000000004RLg`L0oooo00<000000?ooo`3oool0DP3oool00`2oM0000000000000020000000307Bo
o`3oool0oooo02P0oooo0P0000000`0004P0W=oo0?ooo`040?ooo`040?oOW0180000000004RLg`@0
oooo0P00000?0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02`3oool2000007P0
oooo00<000000?ooo`3oool03@3oool000`0oooo00<0oooO09a8001d_ol01@3oool00`2oM0000000
07Boo`0V0?ooo`040=nLB0000000000007Boo`D0oooo00@0okmd000000000000M;oo1`3oool00`00
0000oooo0?ooo`210?ooo`050000003OW4P000000000001d_ol01@3oool0103o_g@000000000001d
_ol30?ooo`8000003`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo0P00
000=0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03@3oool000`0oooo00T0oooO
09a800000000001809cOo`3oool0_g@00000001d_ol0:03oool0103ogi`0B00000000018W=l50?oo
o`040=nLB0000000001809cOo`L0oooo00<000000?ooo`3oool0O`3oool2000000050?ooo`3ogi`0
B00000000018W=l01@3oool0103OW4P000000000B02Lgol20?ooo`800000403oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00X0oooo0P00000=0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool03@3oool000`0oooo00<0oooO09a8000000000`0000000`1d_ol0oooo0?oo
o`0X0?ooo`040?oog`2LB0000000001d_`D0oooo00@0_g@000000000B9`0gooo1`3oool00`000000
oooo0?ooo`1o0?ooo`070000003oool0oooo0?oog`2LB0000000001d_`050?ooo`050;md00000000
04RL0=ooo`3oool00P00000@0?ooo`030000003oool0oooo01X0oooo0P00000=0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0=0?ooo`00303oool0
0`3ooml0W4P0000000050000000304RLg`3oool0oooo02L0oooo00@0okmd00000000B9`0gooo0`3o
ool0103ookl0M0000000001d_ol80?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
0P3oool0103o_g@000000018W03Oool30?ooo`040?oo_`1d0000000007Boo`<00000;@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`0=0?ooo`00303oool01@3ooml0W4Qd0;ooo`3oool0okmd00D0000000<0B9cO0?oo
o`3oool09P3oool00`2oM000000007Boo`030?ooo`030?noM000000007Bo00T0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`040?ooo`030;md00000000M;oo00<0oooo00@0okmd0000
0000M;l000004@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo0P00000<
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool03@3oool000`0oooo00<0oooO09bL
_`3oool00`3oool00`3ookl0M0000000000300000003001d_`3oool0oooo02@0oooo00T0oooO09a8
000004P0W=oo0?ooo`3ogi`0B0000018W03Oool02@3oool00`000000oooo0?ooo`1k0?ooo`800000
1`3oool02@3ooml0W4P00000B02Lgol0oooo0?oOW018000004RL0=ooo`02000000l0oooo00<00000
0?ooo`3oool01@000?lG0?ooo`030000003oool0oooo00X0oooo0P00000=0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool03@3oool001D0oooo00<0_g@00000000000000P0000000`00
B9`0gooo0?ooo`0T0?ooo`050=nLB0000000000000000018W=l02`3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo00T0oooo00H0gia8000000000000000004RLg`3oool2000000l0oooo
00<000000?ooo`3oool01`000?lD0?ooo`800000303oool2000000d0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`0=0?ooo`005`3oool01@3OW4P000000000000007@0_ooo03D0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0>0?ooo`<000003`3oool00`000000oooo
0?ooo`020?ooo`H0003o4`3oool00`000000oooo0?ooo`0;0?ooo`8000003@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo00d0oooo000D0?ooo`050?noM000000000000000M02oool0
>03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00h0oooo0P00000@0?ooo`030000
003oool0oooo00<0oooo1@000?lC0?ooo`030000003oool0oooo00/0oooo0P0000210?ooo`030000
003oool0oooo00d0oooo000<0?ooo`030?oog`2LW;l0oooo0080oooo00D0_g@000000000000004RL
0=ooo`0k0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
000000210?ooo`030000003oool0oooo00d0oooo000<0?ooo`060?oog`2LM9`0gmnL04P000000000
B9cO?`3oool2000007P0oooo00<000000?ooo`3oool03P3oool2000000l0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000`0oooo00<000000?ooo`3o
ool0L@3oool3000000l0oooo000<0?ooo`040?oog`2LB00004RL0=oood40oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0>0?ooo`8000003`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00X0oooo1000000<0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool03@3oool000`0oooo00<0oooO09adW03Oool0@P3oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo00h0oooo0P00000]0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
3@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000=0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0P00000M0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo00d0oooo001A0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool20000
00d0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0=0?ooo`004P3oool00`3ooml0
W9bo0?ooo`0:0?ooo`030=nLW02oool0oooo02l0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0;0?ooo`8000003@3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00d0
oooo000B0?ooo`030?noM018W=l0oooo00X0oooo00<0_gAd0;ooo`3oool0;`3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool02`3oool2000000d0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0=0?ooo`004@3oool00`3ooml0W4P00000000;000000030000M02oool0oooo02l0oooo00<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`0=0?ooo`8000003`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00X0oooo0`00002;0?ooo`030000003oool0oooo00d0oooo000A
0?ooo`030?noM0000000000000/0000000<0001d0;ooo`3oool0;`3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo01/0oooo0P00000<
0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`2oM7@0_ooo0?ooo`0_0?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0000000=0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool03@3oool001l0oooo00<0gibL0;ooo`3oool0;`3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0803oool60000o`D0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0000000=0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool03@3oool00540oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool60000o`@0oooo00<000000?ooo`3oool0
303oool2000000d0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0=0?ooo`00D@3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0A0?ooo`L0003o0`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0=0?ooo`00D@3oool2
000006X0oooo00<000000?ooo`3oool03P3oool2000000h0oooo00<000000?ooo`3oool04`3oool6
0000o`80oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo07l0oooo0`00000?0?ooo`00D@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo
00h0oooo0P00000>0?ooo`030000003oool0oooo01@0oooo1@000?l20?ooo`030000003oool0oooo
00/0oooo0`00000=0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool03@3oool00540
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0=0?ooo`<000003P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000003@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0303oool00`000000oooo0000000>0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0000002D0?ooo`030000003oool0oooo00d0oooo
001A0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool03@3oool2000000h0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo00d0oooo0P00000>0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0=
0?ooo`00D@3oool00`000000oooo0?ooo`1S0?ooo`8000003`3oool2000002`0oooo00<000000?oo
o`3oool0303oool2000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0=0?oo
o`00D@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00h0oooo0P00000>0?ooo`03
0000003oool0oooo01X0oooo0P00000>0?ooo`800000303oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
303oool3000000d0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0=0?ooo`00D@3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0
oooo05l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000=0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0;0?ooo`80000000<0oooo0000003oool02`3oool2000008h0oooo00<000000?oo
o`3oool03@3oool00540oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo000009d0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3o
ool0G03oool00`000000oooo0?ooo`0>0?ooo`8000003P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00/0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00d0oooo001A0?ooo`800000G@3oool00`000000oooo0?ooo`0=0?ooo`80
00003P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`00
00000000303oool00`000000oooo0?ooo`2>0?ooo`<000003`3oool00540oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02T0oooo0P00000=0?ooo`03
0000003oool0000000d0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0=0?ooo`00
D@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo00d0oooo001A0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool03@3oool0
0540oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0=0?ooo`8000003P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000003@3oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo00d0oooo000l0?ooo`030?noM0000000000000T0
000000<0B9cO0?ooo`3oool01P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00d0
oooo0P00000>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0303oool3000000`0
oooo0P00002H0?ooo`030000003oool0oooo00d0oooo000m0?ooo`030?noM0000000000000P00000
00<004RL0=ooo`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00d0oooo
0P00000>0?ooo`030000003oool0oooo01P0oooo0P00000=0?ooo`<00000Z03oool00`000000oooo
0?ooo`0=0?ooo`00?P3oool00`3ogi`0B01d0;ooo`060?ooo`030?oo_`1d0000M;oo00L0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0=0?ooo`8000003P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000003@3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo00d0oooo000o0?ooo`030?oOW01807@0_ooo00H0oooo00<0oono
07Ad_`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00d0oooo0P00000?
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000=
0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool03@3oool00400oooo00<0okmd0000
M02oool03P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00d0oooo0P00000?0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000=0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool03@3oool00440oooo00<0okmd0018W03O
ool03@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00d0oooo0P00000X0?ooo`80
00003P3oool00`000000oooo0000000=0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool03@3oool00480oooo00<0gia80018W03Oool0303oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo00d0oooo00130?ooo`030;md0000M;l0oooo00/0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0=0?ooo`00@`3oool00`3ookl0M00004RLg`0;0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000=0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool03@3oool004@0oooo00<0okmd0000001d_ol02P3oool30000
04d0oooo00<000000?ooo`3oool03@3oool3000000d0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0WP3oool30000
00l0oooo00140?ooo`040?oog`2LB000001d0;ooo`T0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool000000;40oooo00<000000?ooo`3oool03@3oool004D0
oooo00<0gia800000018W=l02@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0F0?ooo`8000003P3oool00`000000
oooo0000000<0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool03@3oool004D0oooo
00@0omnL04P0000007@0_ooo203oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00d0
oooo00150?ooo`040?oo_`1d0000000007Boo`P0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0=0?ooo`<00000303oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo00d0
oooo00150?ooo`040?oOW0180000000004RLg`P0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0=0?ooo`8000003@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00d0
oooo000l0?ooo`030?oog`2LM9`0gooo00H0oooo00@0okmd000000000000B9cO203oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000009@3oool2000000h0
oooo0P00000>0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool03@3oool003d0oooo
00<0gia804RLg`3oool0103oool01@3ookl0M0000000000004P0W=oo00P0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`0=0?ooo`00?@3oool0103ookl0M0000018W03Oool20?ooo`05
0?oOW0180000000000000000M;l02@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00`0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool03@3oool3000000d0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0=
0?ooo`00?P3oool00`3o_g@0000000000005000000030018W03Oool0oooo00P0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000303oool0
0`000000oooo0?ooo`0D0?ooo`8000003P3oool3000000h0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`0=0?ooo`00?`3oool00`3ooml0W4P0000000030000000307Boo`3oool0oooo
00T0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`000000_03oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00d0oooo0`00000=0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<
0?ooo`<000003P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo00d0oooo001A0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000=
0?ooo`030000003oool0oooo0180oooo0P00000>0?ooo`030000003oool0000000h0oooo00<00000
0?ooo`3oool0[`3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool200000480oooo00<000000?oo
o`3oool0303oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0000000>0?ooo`030000003oool0oooo0:h0oooo0`00000?
0?ooo`00D@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`0000003@3oool00`000000oooo0?ooo`0A0?ooo`8000003`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0;40oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000200oooo00<000000?oo
o`3oool03P3oool00`000000oooo0000000>0?ooo`030000003oool0oooo0;80oooo00<000000?oo
o`3oool03@3oool00540oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`<0
00003P3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`8000003`3oool00`000000
oooo0?ooo`2d0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool000000<H0oooo
00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003@3oool00`000000oooo0?oo
o`2g0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool03`3o
ool200000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2h0?ooo`030000003o
ool0oooo00d0oooo001A0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool03P3oool200000140oooo0P00
000>0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool03@3oool00540oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000303o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo0P00000>0?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo0P00000>0?ooo`030000003oool0
oooo0;/0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0;0?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03`3oool3000000d0oooo0P00002n0?ooo`030000003oool0oooo
00d0oooo001A0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0I0?ooo`8000004@3oool2000000h0oooo00<000000?ooo`3oool0_P3oool00`000000
oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo
0P00000?0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool03@3oool00540oooo0P00
000e0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo0P00000A0?ooo`800000d03oool3000000l0oooo001A
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool200000180oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo00d0oooo001A0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?oo
o`8000003`3oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo00d0oooo001A0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool2000001<0oooo0P00000?0?ooo`03
0000003oool0oooo0<<0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo0P00000?0?ooo`030000
003oool0oooo0<@0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03@3o
ool200000<L0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`070?ooo`8000004`3oool2000000l0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool200000100oooo00<000000?ooo`3oool0b03oool00`00
0000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0403oool2000001<0oooo0P00003L0?ooo`030000003oool0oooo00d0
oooo001A0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0>0?ooo`800000503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`3<0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0P000004
0?ooo`800000503oool200000100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0=
0?ooo`00D@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`<00000503oool3
00000100oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`040000003oool00000000001H0oooo0`00000@0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool03@3oool00540oooo0P00000Y0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool2000000@0oooo0`00000G0?ooo`8000004@3oool00`00
0000oooo0?ooo`3>0?ooo`<000003`3oool00540oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo1@00000H0?ooo`8000004@3oool00`000000
oooo0?ooo`3A0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01H0oooo
0P00000A0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool03@3oool00540oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`3V0?ooo`030000003oool0oooo00d0oooo001A
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0D
0?ooo`8000004@3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo00d0oooo00140?oo
o`040=nLB0000000001d0;ooo`T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02T0oooo0`00000A0?ooo`030000003oool0oooo00L0oooo00<0omnL
04P0000000000P0000001000M;l0oooo0?oog`2LB002000000030000M02oool0oooo02T0oooo00D0
_g@0000000000000000007Boo`070?ooo`040?oOW0180000001809cOo`80oooo00<0okmd00000000
00002@0000000`18W=l0oooo0?ooo`1g0?ooo`030000003oool0oooo00d0oooo00140?ooo`040=nL
B0000000001d0;ooo`T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02L0oooo0P0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo00L0
oooo00@0okmd000000000000M;oo0P3oool02@3o_g@0001807AdB0000000001d0;ooo`3ookl0M4RL
0=ooo`0W0?ooo`090?oo_`1d0000001d0;ooo`3oool0okmd00000000B9`0gooo00D0oooo00@0_g@0
00000000000007Bo0`3oool00`3o_g@0000000000008000000030018W03Oool0oooo07L0oooo00<0
00000?ooo`3oool03@3oool004@0oooo00@0gia80000000007@0_ooo2@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0@0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`8000002@3oool0103ooml0W4P00000
0000M;l40?ooo`080?oo_`1d000000000018W03Oool0oooo0?oOW01dW=lV0?ooo`040?oog`2LB000
000007Boo`<0oooo00<0okmd00000000M;l01@3oool0103ogi`0B0000000B02Lgol40?ooo`030?oO
W01807@0_ooo00H0oooo00<0oono07@0001d_ol0N03oool00`000000oooo0?ooo`0=0?ooo`00A03o
ool0103OW4P000000000M02oool90?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P00000@0?ooo`030000003oool0oooo00T0oooo00@0omnL04P000000000B9cO1@3oool0103o_g@0
00000018W03Oool=0?ooo`030?oo_`1d0000000000d0000000<0M;oo0?ooo`3oool02@3oool0103o
_g@000000018W03Oool30?ooo`040?oo_`1d0000000007Boo`d0oooo00<0omnL04P0M02oool01P3o
ool00`3ookl0M7Bo0?ooo`1g0?ooo`030000003oool0oooo00d0oooo00140?ooo`040=nLB0000000
001d0;ooo`T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000@0?ooo`800000
303oool0103ogi`0B0000000001d_ol50?ooo`040?oo_`1d0000000007Boo`d0oooo00<0oono07@0
000000003@0000000`1d_ol0oooo0?ooo`080?ooo`040?oog`2LB000000004RLg`D0oooo00<0_g@0
00000000M;l03P3oool00`3o_g@0001d0;ooo`1o0?ooo`030000003oool0oooo00d0oooo000l0?oo
o`030?noM0000000000000X0000000<007Bo0?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool0103ogi`0B00000000018W=l6
0?ooo`040;md00000000001d0;ooobL0oooo00@0omnL04P000000000M;oo1@3oool0103OW4P00000
0000B02Lgol>0?ooo`030?noM000B9`0gooo07h0oooo00<000000?ooo`3oool03@3oool003`0oooo
00<0okmd0000000000002P0000000`00M;l0oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo
0P0000020?ooo`800000803oool0103ookl0M00000000000M;l60?ooo`050=nLB0000000B4Q80018
W03Oool09P3oool0103OW4P000000000B02Lgol50?ooo`040?noM0000000000007Boo`l0oooo00<0
gia80018W03Oool0O@3oool00`000000oooo0?ooo`0=0?ooo`00?03oool00`3ooml0W4P007Boo`05
0?ooo`040=nLB0000000001d0;ooo`T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool2000000<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`040=nLB000000004RL0=ooo`D0oooo
00D0okmd00000000B9`0W7@004RLg`0V0?ooo`040;md00000000001809cOo`D0oooo00@0okmd0000
00000000B9cO403oool00`2oM00007Bo0?ooo`1l0?ooo`030000003oool0oooo00d0oooo000m0?oo
o`030?noM000B9`0gooo00@0oooo00@0gia80000000007@0_ooo2@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`07
0?ooo`800000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00@0oono
07@000000000M;oo1@3oool01P3ogi`0B0000000M02ogi`0B00007Boob@0oooo00D0oooO09a80000
0000001d0;ooo`050?ooo`040?oOW01800000000001d_a00oooo00<0oono07@00018W=l0O03oool0
0`000000oooo0?ooo`0=0?ooo`00?P3oool00`2oM000B9cO0?ooo`030?ooo`040=nLB0000000001d
0;ooo`T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0W0?ooo`8000001@3oool2
000000@0oooo0P00000A0?ooo`030000003oool0oooo0180oooo00<0okmd00000000M;l01@3oool0
1`3o_g@000000000M02oool0gia80000M02oool02@3oool00`3ookl0M0000000000=0000000307Bo
o`3oool0oooo00L0oooo00D0oooO09a800000000001d0;ooo`050?ooo`040?oOW01800000000001d
_a40oooo00<0okmd0000001d_ol0N`3oool00`000000oooo0?ooo`0=0?ooo`00?P3oool00`3ookl0
M01809cOo`030?ooo`040=nLB0000000001d0;ooo`T0oooo0`00000K0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool00P0000040?ooo`8000004P3oool00`000000oooo0?ooo`0D0?oo
o`030=nLB0000000M;oo00@0oooo00L0gia800000000B9`0gooo0?oo_`1d000007Bo00T0oooo00<0
oono07@0000000003@0000000`1d_ol0oooo0?ooo`070?ooo`050?oog`2LB00000000000M02oool0
1@3oool0103ogi`0B00000000000M;lA0?ooo`040?oog`2LB000001d0;ooogP0oooo0`00000?0?oo
o`00?`3oool00`3o_g@004RL0=ooo`020?ooo`040=nLB0000000001d0;ooo`T0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0F0?ooo`030?noM0000000B9cO0080oooo00@0omnL04P0
00000000M;oo0P3oool00`3OW4P00000001d_`0S0?ooo`040;md00000000001809cOo`D0oooo00@0
omnL04P00000000007Bo4P3oool00`3OW4P0000004RLg`1j0?ooo`030000003oool0oooo00d0oooo
00100?ooo`080;md0018W=l0oooo0?ooo`3OW4P000000000M02oool90?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0100oooo0P00000K0?ooo`030;md0000000000000080000000<0M;oo0?ooo`3oool09`3oool0102o
M00000000000B02Lgol50?ooo`040?oOW0180000000004RLga80oooo00@0omnL04P0000007@0_ooo
N@3oool00`000000oooo0?ooo`0=0?ooo`00@03oool0203ookl0M01809cOo`3oool0gia800000000
07@0_ooo2@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool08`3oool200000180oooo00<000000?ooo`3oool0BP3oool0103OW4P000000000001d_ol5
0?ooo`040?noM0000000000007Booa80oooo00@0oono07@000000000M;ooN@3oool00`000000oooo
0?ooo`0=0?ooo`00@@3oool01`3o_g@004RL0=ooo`3OW4P000000000M02oool02@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo04/0oooo00@0omnL04P000000000B9cO1@3oool0103O
W4P000000000B02LgolB0?ooo`040?oOW0180000000004RLggT0oooo00<000000?ooo`3oool03@3o
ool00480oooo00H0_g@007Boo`3OW4P000000000M02oool90?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0600oooo
00@0oooO09a80000000007Bo1@3oool0102oM00000000018W03Oool90?ooo`030?oog`2LM9`0gooo
00H0oooo00@0okmd000000000000B9cON@3oool00`000000oooo0?ooo`0=0?ooo`00@P3oool01P3o
okl0M01d09bLB0000000001d0;ooo`T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool200000540oooo00@0
okmd00000000B9`0gooo0`3oool0103ookl0M0000000001d_ol;0?ooo`030=nLB018W=l0oooo00@0
oooo00D0oono07@000000000001809cOo`1i0?ooo`030000003oool0oooo00d0oooo00130?ooo`05
0?noM000000000000000M02oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0540oooo00<0_g@00000001d_ol00`3oool00`3o_g@00000001d_`0<0?ooo`040?oo_`1d000004RL
0=ooo`80oooo00D0omnL04P0000000000000001d_`1j0?ooo`030000003oool0oooo00d0oooo0014
0?ooo`040;md00000000001d0;ooo`T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`090?ooo`8000008`3oool2000006L0oooo00T0oooO09a8000004P0W=oo0?ooo`3ogi`0B0000018
W03Oool03@3oool00`3o_g@0000000000005000000030018W03Oool0oooo07T0oooo00<000000?oo
o`3oool03@3oool004@0oooo00@0oono07@0000007@0_ooo2@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1F0?oo
o`050=nLB0000000000000000018W=l0403oool00`3ooml0W4P0000000030000000307Boo`3oool0
oooo07X0oooo00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0k`3oool00`00
0000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`800000lP3oool00`000000
oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0803oool200000140oooo00<000000?ooo`3oool0lP3oool00`000000oooo
0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?<0oooo00<0
00000?ooo`3oool03@3oool00540oooo0P00000B0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool07P3oool200000140oooo0P00003d0?ooo`<000003`3oool00540oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`3f0?ooo`030000003oool0oooo00d0oooo001A0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`80
0000o`3oool=0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0?X0oooo00<000000?ooo`3oool03@3oool00540oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo0P00000A
0?ooo`800000o@3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3m0?oo
o`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0J0?ooo`8000004P3oool00`000000oooo0?ooo`3n0?ooo`03
0000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo0P00003o0?ooo`80oooo
00<000000?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01P0oooo0P00000B0?ooo`030000003oool0oooo0?l0oooo0P3o
ool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool05P3oool200000?l0oooo6@3oool00`000000oooo0?ooo`0=
0?ooo`00D@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo103oool00`00
0000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`800000o`3oool70?ooo`03
0000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0E0?ooo`8000004`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo
00<000000?ooo`3oool03@3oool00540oooo0P00000:0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`800000o`3oool80?ooo`<000003`3o
ool00540oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01@0oooo0P00000C0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000oooo0?ooo`0=
0?ooo`00D@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool04@3oool200000?l0oooo3@3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo0P00000C0?ooo`030000003oool0oooo0?l0
oooo3@3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool200000?l0oooo9@3oool00`000000oooo
0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo3`3o
ool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03`3oool2000001@0oooo0P00003o0?oooa80oooo00<00000
0?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo0P00000D0?ooo`800000o`3ooolD0?ooo`030000003oool0oooo
00d0oooo001A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0<0?ooo`800000503oool200000?l0oooo5P3oool00`000000oooo0?ooo`0=0?ooo`00
D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool2000001@0oooo0P00003o0?oooaP0oooo00<000000?ooo`3oool03@3oool00540oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo0P00
000E0?ooo`030000003oool0oooo0?l0oooo603oool00`000000oooo0?ooo`0=0?ooo`00D@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool2
00000?l0oooo<P3oool00`000000oooo0?ooo`0=0?ooo`00D@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool2000001L0oooo00<000000?oo
o`3oool0o`3ooolJ0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo00H0
oooo0P0000030?ooo`030000003oool0oooo00<0oooo1000000G0?ooo`800000o`3ooolM0?ooo`03
0000003oool0oooo00d0oooo001A0?ooo`8000002@3oool2000000<0oooo1000000J0?ooo`030000
003oool0oooo0?l0oooo6`3oool3000000l0oooo001A0?ooo`030000003oool0oooo00X0oooo0`00
000L0?ooo`800000o`3ooolP0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooob00oooo00<00000
0?ooo`3oool03@3oool00540oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?oo
o`800000o`3ooolS0?ooo`030000003oool0oooo00d0oooo001A0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?ooob<0oooo00<000000?ooo`3o
ool03@3oool00400oooo00<0oooO09a8000000000P0000000`0007@0_ooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooobH0oooo
00<000000?ooo`3oool03@3oool003l0oooo00@0omnL04P0000004P0W=oo0P3oool00`3OW4P00000
04RLg`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool200000?l0oooo
:@3oool00`000000oooo0?ooo`0=0?ooo`00?P3oool0103ogi`0B0000000001d_ol40?ooo`030=nL
B0000000M;oo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`800000
o`3oool[0?ooo`030000003oool0oooo00d0oooo000m0?ooo`040?oog`2LB0000000001d_`D0oooo
00@0omnL04P0000007@0_ooo1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0100
oooo0P00003o0?ooobd0oooo00<000000?ooo`3oool03@3oool003d0oooo00@0omnL04P000000000
M;oo1@3oool0103ooml0W4P00000001d_ol70?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03@3oool200000?l0oooo;`3oool00`000000oooo0?ooo`0=0?ooo`00?@3oool0103OW4P0
00000000B02Lgol50?ooo`040?oog`2LB0000000001d_`L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo;`3oool00`000000oooo0?ooo`0=
0?ooo`00?@3oool0102oM00000000000M02oool50?ooo`040?oo_`1d00000000001d_`L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`800000o`3ooold0?ooo`030000003o
ool0oooo00d0oooo000l0?ooo`050?oog`2LB00000000000M02oool01@3oool0103ogi`0B0000000
0000M;l70?ooo`030000003oool0oooo0180oooo0`00003o0?ooocH0oooo00<000000?ooo`3oool0
3@3oool003`0oooo00D0oooO09a800000000001809cOo`050?ooo`040=nLB0000000000007Boo`L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000200000?l0oooo>@3oool00`000000
oooo0?ooo`0=0?ooo`00?@3oool0102oM00000000000B02Lgol40?ooo`050?oo_`1d000000000000
M02oool01`3oool3000000d0oooo0P00003o0?ooocX0oooo0`00000?0?ooo`00?@3oool0303OW4P0
0000000000000000001d0;ooo`3oool0oono07@000000000001809cOo`P0oooo00<000000?ooo`3o
ool0o`3ooom;0?ooo`030000003oool0oooo00d0oooo000m0?ooo`060?noM00000000000001d_`3o
okl0M0000`0000000`00B9`0gooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooB`3oool00`00
0000oooo0?ooo`0=0?ooo`00?@3oool01@3ooml0W4P00000000007@0_ooo00l0oooo00<000000?oo
o`3oool0o`3ooom;0?ooo`030000003oool0oooo00d0oooo000n0?ooo`040?noM0000000000004RL
g`l0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`030000003oool0oooo00d0oooo000n0?ooo`05
0?oog`2LB00000000000M02oool03P3oool00`000000oooo0?ooo`3o0?oood/0oooo00<000000?oo
o`3oool03@3oool003l0oooo00@0omnL04P00000000007Bo3P3oool2000000P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00100?ooo`04
0?oOW01800000000001d_`d0oooo0P0000080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00@@3oool01@3ogi`0B00000000000B9`0gooo
00/0ooooo`00001?000000l0oooo00130?ooo`040;md000000000000001d_ol0ooooJ03oool004D0
oooo00D0gia8000000000000000007Boo`3o0?ooofD0oooo003o0?ooojl0oooo003o0?ooojl0oooo
003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo
003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo003o0?ooojl0oooo
003o0?ooojl0oooo0000\
\>"],
  ImageRangeCache->{{{0, 429}, {429, 0}} -> {-2.34286, -8.27779, 0.005362, \
0.0351726}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\<fig5.eps\>", finalall, "\<EPS\>", 
      ImageSize \[Rule] 800]\)], "Input"],

Cell[BoxData[
    \("fig5.eps"\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 717}},
WindowSize->{1274, 683},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 138, 3, 41, "Input"],
Cell[1895, 56, 162, 4, 41, "Input"],
Cell[2060, 62, 840, 21, 95, "Input"],
Cell[2903, 85, 427, 17, 33, "Input"],
Cell[3333, 104, 311, 10, 27, "Input"],
Cell[3647, 116, 83, 2, 41, "Input"],
Cell[3733, 120, 349, 7, 112, "Input"],
Cell[4085, 129, 86, 2, 41, "Input"],
Cell[4174, 133, 467, 8, 117, "Input"],
Cell[4644, 143, 423, 17, 33, "Input"],
Cell[5070, 162, 749, 15, 78, "Input"],

Cell[CellGroupData[{
Cell[5844, 181, 379, 8, 46, "Input"],
Cell[6226, 191, 181, 3, 22, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6444, 199, 284, 8, 49, "Input"],
Cell[6731, 209, 136, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6904, 216, 167, 5, 27, "Input"],
Cell[7074, 223, 135, 2, 26, "Output"]
}, Open  ]],
Cell[7224, 228, 115, 2, 41, "Input"],

Cell[CellGroupData[{
Cell[7364, 234, 948, 20, 78, "Input"],
Cell[8315, 256, 114, 2, 26, "Output"],
Cell[8432, 260, 110, 2, 26, "Output"],
Cell[8545, 264, 115, 2, 26, "Output"],
Cell[8663, 268, 109, 2, 26, "Output"]
}, Open  ]],
Cell[8787, 273, 86, 2, 41, "Input"],

Cell[CellGroupData[{
Cell[8898, 279, 1086, 23, 78, "Input"],
Cell[9987, 304, 242, 6, 26, "Output"],
Cell[10232, 312, 242, 6, 26, "Output"],
Cell[10477, 320, 72277, 1936, 296, 26966, 1372, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82791, 2261, 77, 1, 27, "Input"],
Cell[82871, 2264, 58, 1, 26, "Output"]
}, Open  ]],
Cell[82944, 2268, 205, 4, 59, "Input"],
Cell[83152, 2274, 87, 1, 27, "Input"],
Cell[83242, 2277, 92, 2, 34, "Input"],
Cell[83337, 2281, 677, 14, 78, "Input"],

Cell[CellGroupData[{
Cell[84039, 2299, 324, 7, 27, "Input"],
Cell[84366, 2308, 129244, 3040, 438, 36975, 1896, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[213647, 5353, 106, 2, 27, "Input"],
Cell[213756, 5357, 44, 1, 26, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

